@@ -453,8 +453,6 @@ processOneLibrary(const char *  const filepath,
    linker option string as a newly malloced null-terminated string at
    *optionsP.
 -----------------------------------------------------------------------------*/
-    unsigned int const MAX_OPT_SIZE = 1024;
-
     const char *directory;
         /* Directory component of 'filepath' */
     const char *filename;
@@ -497,16 +495,20 @@ main(int argc, char **argv) {
 
     bool error;
     bool runtime;  /* -runtime option has been seen */
+    bool quiet;    /* -quiet option has been seen */
     int retval;
     unsigned int arg;  /* Index into argv[] of argument we're processing */
     char outputLine[1024];
 
     strcpy(outputLine, "");  /* initial value */
     runtime = FALSE;  /* initial value */
+    quiet = FALSE;   /* initial value */
     error = FALSE;  /* no error yet */
     for (arg = 1; arg < argc && !error; arg++) {
         if (strcmp(argv[arg], "-runtime") == 0)
             runtime = TRUE;
+        else if (strcmp(argv[arg], "-quiet") == 0)
+            quiet = TRUE;
         else {
             if (strlen(argv[arg]) > 200)
                 error = TRUE;
@@ -533,7 +535,8 @@ main(int argc, char **argv) {
         retval = 10;
     } else {
         fputs(outputLine, stdout);
-        fprintf(stderr, "libopt results: '%s'\n", outputLine);
+        if (!quiet)
+            fprintf(stderr, "libopt results: '%s'\n", outputLine);
         retval = 0;
     }
     return retval;
