@@ -29,21 +29,18 @@
  *
 \*/
 
-/* There is a specification of the Windows BMP format in  (2000.06.08)
-   
-   <http://www.daubnet.com/formats/BMP.html>
+/* 
+   There is a specification of BMP (2003.07.24) at:
 
-   However, the format we have seen for Windows BMP files with 24 bit
-   truecolor is quite a bit different, and zgv seems to know it too:
+     http://msdn.microsoft.com/library/default.asp?url=/library/en-us/gdi/bitmaps_4v1h.asp
 
-   The raster is 3 bytes per pixel, in the order G, B, R with each
-   row padded out to a multiple of 4 bytes.  The above document says
-   it is 4 bytes per pixel, in the order R, G, B, Z (zero).
+   There is a better written specification of the Windows BMP format
+   in (2000.06.08) <http://www.daubnet.com/formats/BMP.html>.
+   However, the "Windows BMP" format used in practice is much closer
+   to the Microsoft definition.  The Microsoft spec was not known for
+   Netpbm development until 2003.07.24.
 
-   And the colormap format is also different: Each color entry is in
-   the order B, G, R, Z whereas the document says R, G, B, Z.
-
-   The ColorsImportant field is defined in that spec as "Number of
+   The ColorsImportant field is defined in the daubnet spec as "Number of
    important colors.  0 = all"  That is the entire definition.  The
    spec also says the number of entries in the color map is a function
    of the BitCount field alone.
@@ -90,6 +87,12 @@ enum bmpClass {C_WIN=1, C_OS2=2};
 
 static char     er_internal[] = "%s: internal error!";
 
+/* Values of the "compression" field of the BMP info header */
+#define COMP_RGB       0
+#define COMP_RLE8      1
+#define COMP_RLE4      2
+#define COMP_BITFIELDS 3
+
 static unsigned int
 BMPlenfileheader(enum bmpClass const class) {
 
