@@ -1,5 +1,7 @@
 #define _BSD_SOURCE
-    /* Make sure setenv is in stdlib.h and strcasecmp is in string.h */
+    /* Make sure strcasecmp is in string.h */
+#define _XOPEN_SOURCE
+    /* Make sure putenv is in stdlib.h */
 
 #include <stdlib.h>
 #include <string.h>
@@ -1253,7 +1255,7 @@ parse_rollei(FILE * const ifp)
   } while (strncmp(line,"EOHD",4));
   t.tm_year -= 1900;
   t.tm_mon -= 1;
-  setenv ("TZ", "", 1);
+  putenv((char*)"TZ=");
   if ((ts = mktime(&t)) > 0)
     timestamp = ts;
   data_offset += tx * ty * 2;
@@ -1460,7 +1462,7 @@ get_timestamp()
     return;
   t.tm_year -= 1900;
   t.tm_mon -= 1;
-  setenv ("TZ", "UTC", 1);      /* Remove this to assume local time */
+  putenv((char*)"TZ=UTC");   /* Remove this to assume local time */
   if ((ts = mktime(&t)) > 0)
     timestamp = ts;
 }
