@@ -22,6 +22,7 @@
 */
 
 #define _XOPEN_SOURCE    /* Make sure stdio.h contains fileno() */
+#define _BSD_SOURCE      /* Make sure string.h contains strcasecmp() */
 
 #include <unistd.h>
 #include <stdio.h>
@@ -36,11 +37,13 @@
 
 #include <string.h>
 
-#include "pam.h"
-#include "pammap.h"
+#include "pm_c_util.h"
 #include "shhopt.h"
 #include "mallocvar.h"
 #include "nstring.h"
+#include "pam.h"
+#include "pammap.h"
+#include "pm_tiff.h"
 
 #define MAXCOLORS 256
 
@@ -53,12 +56,17 @@ struct sizeset {
     bool b1, b2, b4, b8;
 };
 
+
 struct cmdlineInfo {
     /* All the information the user supplied in the command line,
        in a form easy for the program to use.
     */
     const char *input_filespec;  /* Filespecs of input files */
-    int compression;   /* COMPRESSION Tiff tag value */
+    int compression;
+        /* COMPRESSION Tiff tag value, that corresponds to the compression
+           option the user specified, or -1 if he didn't specify any.
+           The -tag option doesn't count.
+        */
     int fillorder;     /* FILLORDER Tiff tag value */
     int g3options;     /* G3OPTIONS Tiff tag value or 0 for none */
     int predictor;     /* PREDICTOR Tiff tag value or -1 for none */
@@ -74,10 +82,56 @@ struct cmdlineInfo {
     /* Which bit widths are allowable in a raster of palette indices */
     unsigned int verbose;
     unsigned int append;
+    float resolution;  /* X and Y resolution */
+    struct optNameValue * taglist;
 };
 
 
 
+static void
+validateTagList(struct optNameValue const taglist[]) {
+
+    unsigned int i;
+    for (i = 0; taglist[i].name; ++i) {
+        const char * const tagName = taglist[i].name;
+        const tagDefinition * tagDefP = tagDefFind(tagName);
+        
+        if (!tagDefP)
+            pm_error("Unknown tag name '%s'", tagName);
+        else {
+            /* We don't allow the user to set directly any tag that we
+               control explicitly.  These are normally tags that have to be
+               consistent with other stuff we put in the image.  But in some
+               cases, they're just tags we had special options for before
+               -tag existed.  The latter should probably be converted
+               eventually to prefer -tag.
+            */
+            switch (tagDefP->tagnum) {
+            case TIFFTAG_IMAGEWIDTH:
+            case TIFFTAG_IMAGELENGTH:
+            case TIFFTAG_BITSPERSAMPLE:
+            case TIFFTAG_COMPRESSION:
+            case TIFFTAG_GROUP3OPTIONS:
+            case TIFFTAG_PREDICTOR:
+            case TIFFTAG_PHOTOMETRIC:
+            case TIFFTAG_FILLORDER:
+            case TIFFTAG_SAMPLESPERPIXEL:
+            case TIFFTAG_ROWSPERSTRIP:
+            case TIFFTAG_PLANARCONFIG:
+            case TIFFTAG_COLORMAP:
+            case TIFFTAG_RESOLUTIONUNIT:
+            case TIFFTAG_XRESOLUTION:
+            case TIFFTAG_YRESOLUTION:
+                pm_error("You cannot specify a '%s' tag with -tag.  "
+                         "Pamtotiff controls that internally or via other "
+                         "options.", tagName);
+            }
+        }
+    }
+}
+
+
+
 static void
 parseCommandLine(int                        argc,
                  char **              const argv,
@@ -96,7 +150,7 @@ parseCommandLine(int                        argc,
     char * resolutionUnit;
 
     unsigned int predictorSpec, rowsperstripSpec, xresolutionSpec,
-        yresolutionSpec, indexbitsSpec, resolutionUnitSpec;
+        yresolutionSpec, indexbitsSpec, resolutionUnitSpec, tagSpec;
 
     unsigned int option_def_index;
 
@@ -132,8 +186,9 @@ parseCommandLine(int                        argc,
             &yresolutionSpec,  0);
     OPTENT3(0, "resolutionunit", OPT_STRING, &resolutionUnit,
             &resolutionUnitSpec,    0);
-    OPTENT3(0, "indexbits",    OPT_STRING, &indexbits, 
+    OPTENT3(0, "indexbits",    OPT_STRING,   &indexbits, 
             &indexbitsSpec,    0);
+    OPTENT3(0, "tag",          OPT_NAMELIST, &cmdlineP->taglist, &tagSpec, 0);
 
     opt.opt_table = option_def;
     opt.short_allowed = FALSE;  /* We have no short (old-fashioned) options */
@@ -257,6 +312,14 @@ parseCommandLine(int                        argc,
         cmdlineP->indexsizeAllowed.b8 = TRUE;
     }
 
+    if (tagSpec)
+        validateTagList(cmdlineP->taglist);
+    else {
+        MALLOCARRAY_NOFAIL(cmdlineP->taglist, 1);
+        cmdlineP->taglist[0].name = NULL;
+        cmdlineP->taglist[0].value = NULL;
+    }
+
     if (argc-1 == 0) 
         cmdlineP->input_filespec = "-";
     else if (argc-1 != 1)
@@ -373,15 +436,46 @@ fillRowOfSubBytePixels(struct pam *    const pamP,
 
 
 static void
-writeScanLines(struct pam *    const pamP,
-               TIFF *          const tif, 
-               tuplehash       const cht,
-               unsigned short  const tiff_maxval,
-               unsigned short  const bitspersample, 
-               unsigned short  const photometric,
-               int             const bytesperrow, 
-               bool            const grayscale,
-               int             const fillorder) {
+fillRowOfWholeBytePixels(struct pam *    const pamP,
+                         tuple *         const tuplerow,
+                         unsigned char * const buf,
+                         unsigned short  const photometric,
+                         unsigned short  const tiffMaxval,
+                         unsigned int    const bitsPerSample) {
+
+    unsigned int col;
+    unsigned char * tP;
+    unsigned int planes;
+    
+    if (photometric == PHOTOMETRIC_RGB)
+        planes = pamP->depth;
+    else
+        /* Write only the first plane from the PAM, even if there
+           are more.
+        */
+        planes = 1;
+
+    for (col = 0, tP = buf; col < pamP->width; ++col) {
+        unsigned int plane;
+        for (plane = 0; plane < planes; ++plane) {
+            putSample(tuplerow[col][plane], pamP->maxval,
+                      tiffMaxval, bitsPerSample, &tP);
+            /* Advances tP */
+        }
+    }
+} 
+
+
+
+static void
+writeScanLines(struct pam *   const pamP,
+               TIFF *         const tif, 
+               tuplehash      const cht,
+               unsigned short const tiffMaxval,
+               unsigned short const bitspersample, 
+               unsigned short const photometric,
+               int            const bytesperrow, 
+               int            const fillorder) {
 /*----------------------------------------------------------------------------
    Write out the raster for the input image described by 'pamP', whose
    file is positioned to the raster of the image.
@@ -417,22 +511,14 @@ writeScanLines(struct pam *    const pamP,
         pnm_readpamrow(pamP, tuplerow);
 
         if (cht == NULL) {
-            /* It's a truecolor raster */
-            unsigned char * tP;
-            unsigned int col;
+            /* It's a direct, non-colormapped raster */
 
-            if (bitspersample == 8 || bitspersample == 16) {
-                for (col = 0, tP = buf; col < pamP->width; ++col) {
-                    unsigned int plane;
-                    for (plane = 0; plane < pamP->depth; ++plane) {
-                        putSample(tuplerow[col][plane], pamP->maxval,
-                                  tiff_maxval, bitspersample, &tP);
-                        /* Advances tP */
-                    }
-                }
-            } else
+            if (bitspersample == 8 || bitspersample == 16)
+                fillRowOfWholeBytePixels(pamP, tuplerow, buf, photometric,
+                                         tiffMaxval, bitspersample);
+            else
                 fillRowOfSubBytePixels(pamP, tuplerow, buf,
-                                       tiff_maxval,photometric,
+                                       tiffMaxval, photometric,
                                        fillorder, bitspersample, NULL);
         } else {
             /* It's a colormapped raster */
@@ -445,7 +531,7 @@ writeScanLines(struct pam *    const pamP,
                     
                     if (!found)
                         pm_error("INTERNAL ERROR.  We made a color map, and a "
-                                 "color map we need is not in it!.  "
+                                 "color map we need is not in it!  "
                                  "col=%d  r=%lu g=%lu b=%lu",
                                  col, tuplerow[col][0], tuplerow[col][1],
                                  tuplerow[col][2]);
@@ -538,6 +624,10 @@ analyzeColors(struct pam *        const pamP,
    of a color map (in newly malloc'ed space).  If a colormapped TIFF is
    not indicated, return *chvP == NULL.
 
+   Return *grayscaleP == true iff the image should be stored as a grayscale
+   image (which means the image is monochromatic and the user doesn't
+   insist on color format).
+
    Leave the file position undefined.
 -----------------------------------------------------------------------------*/
     if (pamP->depth >= 3)
@@ -563,12 +653,10 @@ computeRasterParm(struct pam *     const pamP,
                   bool             const minisblack,
                   bool             const miniswhite,
                   struct sizeset   const indexsizeAllowed,
-                  int              const requested_rowsperstrip,
                   unsigned short * const samplesperpixelP,
                   unsigned short * const bitspersampleP,
                   unsigned short * const photometricP,
-                  int            * const bytesperrowP,
-                  unsigned short * const rowsperstripP) {
+                  int            * const bytesperrowP) {
 /*----------------------------------------------------------------------------
    Compute the parameters of the raster portion of the TIFF image.
 
@@ -588,7 +676,7 @@ computeRasterParm(struct pam *     const pamP,
        backward compatibility requirements.  
     */
 
-    if (pamP->depth < 3 && pamP->maxval == 1) {
+    if (pamP->depth == 1 && pamP->maxval == 1) {
         *samplesperpixelP = 1;
         *bitspersampleP = 1;
         if ((compression == COMPRESSION_CCITTFAX3) ||
@@ -598,7 +686,7 @@ computeRasterParm(struct pam *     const pamP,
             defaultPhotometric = PHOTOMETRIC_MINISBLACK;
     } else {
         if (chv) {
-            *samplesperpixelP = 1;
+            *samplesperpixelP = 1;  /* Pixel is just the one index value */
             *bitspersampleP = 
                 colors <=   2 && indexsizeAllowed.b1 ? 1 :
                 colors <=   4 && indexsizeAllowed.b2 ? 2 :
@@ -612,12 +700,15 @@ computeRasterParm(struct pam *     const pamP,
             defaultPhotometric = PHOTOMETRIC_PALETTE;
         } else {
             if (grayscale) {
+                /* We'll write just the first plane regardless of how many are
+                   in the input PAM.
+                */
                 *samplesperpixelP = 1;
                 *bitspersampleP =
                     pamP->maxval > 255 ? 16 : pm_maxvaltobits(pamP->maxval);
                 defaultPhotometric = PHOTOMETRIC_MINISBLACK;
             } else {
-                *samplesperpixelP = 3;
+                *samplesperpixelP = pamP->depth;
                 *bitspersampleP = pamP->maxval > 255 ? 16 : 8;
                 defaultPhotometric = PHOTOMETRIC_RGB;
             }
@@ -631,21 +722,20 @@ computeRasterParm(struct pam *     const pamP,
     else
         *photometricP = defaultPhotometric;
 
-    if (*bitspersampleP < 8) {
-        int samplesperbyte;
-        samplesperbyte = 8 / *bitspersampleP;
-        *bytesperrowP = 
-            (pamP->width * *samplesperpixelP + samplesperbyte-1) /
-                samplesperbyte;
-    } else 
-        *bytesperrowP =
-            (pamP->width * *samplesperpixelP * *bitspersampleP) / 8;
-
-    if (requested_rowsperstrip == -1 )
-        *rowsperstripP = (8 * 1024) / *bytesperrowP;
-    else 
-        *rowsperstripP = requested_rowsperstrip;
+    {
+        unsigned int const samplesPerRow = pamP->width * *samplesperpixelP;
 
+        if (*bitspersampleP < 8) {
+            int samplesperbyte;
+            samplesperbyte = 8 / *bitspersampleP;
+            *bytesperrowP =
+                (samplesPerRow + samplesperbyte-1) / samplesperbyte;
+        } else {
+            if (UINT_MAX / *bitspersampleP < samplesPerRow)
+                pm_error("Too many bytes per row to compute");
+            *bytesperrowP = (samplesPerRow * *bitspersampleP) / 8;
+        }
+    }
 }
 
 
@@ -773,6 +863,92 @@ destroyTiffColorMap(struct pam *      const pamP,
 
 
 
+static void
+setTagListFields(const struct optNameValue * const taglist,
+                 TIFF *                      const tifP) {
+
+    unsigned int i;
+
+    for (i = 0; taglist[i].name; ++i) {
+        const tagDefinition * const tagDefP = tagDefFind(taglist[i].name);
+        
+        if (tagDefP->put)
+            tagDefP->put(tifP, tagDefP->tagnum, taglist[i].value,
+                         tagDefP->choices);
+    }
+}
+
+
+
+static void
+setTiffFields(TIFF *              const tifP,
+              struct cmdlineInfo  const cmdline,
+              struct pam *        const pamP,
+              unsigned short      const bitspersample,
+              unsigned short      const photometric,
+              unsigned short      const samplesperpixel,
+              unsigned short **   const tiffColorMap,
+              const char *        const inputFileDescription,
+              struct optNameValue const taglist[]) {
+
+    /* TODO: It would be cleaner to set all tags in a tag list and
+       then call setTagListFields() on that list.  That way,
+       TIFFSetField() is in only one place and all tags get set the
+       same way and we don't have this icky setting of default and
+       then resetting with user choice (e.g. DOCUMENTNAME).
+    */
+
+    /* Set TIFF parameters. */
+    TIFFSetField(tifP, TIFFTAG_IMAGEWIDTH,    pamP->width);
+    TIFFSetField(tifP, TIFFTAG_IMAGELENGTH,   pamP->height);
+    TIFFSetField(tifP, TIFFTAG_BITSPERSAMPLE, bitspersample);
+    if (cmdline.compression != -1)
+        TIFFSetField(tifP, TIFFTAG_COMPRESSION, cmdline.compression);
+    if (cmdline.compression == COMPRESSION_CCITTFAX3 && cmdline.g3options != 0)
+        TIFFSetField( tifP, TIFFTAG_GROUP3OPTIONS, cmdline.g3options);
+    if (cmdline.compression == COMPRESSION_LZW && cmdline.predictor != -1)
+        TIFFSetField( tifP, TIFFTAG_PREDICTOR, cmdline.predictor);
+    TIFFSetField(tifP, TIFFTAG_PHOTOMETRIC, photometric);
+    if (cmdline.fillorder != -1)
+        TIFFSetField(tifP, TIFFTAG_FILLORDER, cmdline.fillorder);
+    TIFFSetField(tifP, TIFFTAG_SAMPLESPERPIXEL, samplesperpixel);
+    if (cmdline.rowsperstrip != -1)
+        TIFFSetField(tifP, TIFFTAG_ROWSPERSTRIP, cmdline.rowsperstrip);
+    else
+        TIFFSetField(tifP, TIFFTAG_ROWSPERSTRIP,
+                     TIFFDefaultStripSize(tifP, 0));
+    if (cmdline.xresolution != -1 ||
+        cmdline.yresolution != -1 ||
+        cmdline.resolutionUnit != -1) {
+        TIFFSetField(tifP, TIFFTAG_RESOLUTIONUNIT,
+                     cmdline.resolutionUnit != -1 ?
+                     cmdline.resolutionUnit : RESUNIT_NONE);
+    }
+    if (cmdline.xresolution > 0)
+        TIFFSetField(tifP, TIFFTAG_XRESOLUTION, cmdline.xresolution);
+    if ( cmdline.yresolution > 0)
+        TIFFSetField(tifP, TIFFTAG_YRESOLUTION, cmdline.yresolution);
+    TIFFSetField(tifP, TIFFTAG_PLANARCONFIG, PLANARCONFIG_CONTIG);
+
+    if (tiffColorMap)
+        TIFFSetField(tifP, TIFFTAG_COLORMAP,
+                     tiffColorMap[PAM_RED_PLANE],
+                     tiffColorMap[PAM_GRN_PLANE],
+                     tiffColorMap[PAM_BLU_PLANE]);
+
+
+    TIFFSetField(tifP, TIFFTAG_DOCUMENTNAME,     inputFileDescription);
+    TIFFSetField(tifP, TIFFTAG_IMAGEDESCRIPTION, "converted PNM file");
+ 
+    /* Some of taglist[] overrides defaults we set above.  But taglist[]
+       is defined not to specify any tag types that are not purely user
+       choice.
+    */
+    setTagListFields(taglist, tifP);
+}
+
+
+
 static void
 convertImage(FILE *             const ifP,
              TIFF *             const tifP,
@@ -786,7 +962,6 @@ convertImage(FILE *             const ifP,
     unsigned int colors;
     bool grayscale;
     unsigned short photometric;
-    unsigned short rowsperstrip;
     unsigned short samplesperpixel;
     unsigned short bitspersample;
     unsigned short tiff_maxval;
@@ -811,56 +986,29 @@ convertImage(FILE *             const ifP,
                       cmdline.compression,
                       cmdline.minisblack, cmdline.miniswhite,
                       cmdline.indexsizeAllowed,
-                      cmdline.rowsperstrip,
                       &samplesperpixel, &bitspersample, &photometric,
-                      &bytesperrow, &rowsperstrip);
+                      &bytesperrow);
 
     tiff_maxval = pm_bitstomaxval(bitspersample);
 
-    /* Set TIFF parameters. */
-    TIFFSetField(tifP, TIFFTAG_IMAGEWIDTH,    pam.width);
-    TIFFSetField(tifP, TIFFTAG_IMAGELENGTH,   pam.height);
-    TIFFSetField(tifP, TIFFTAG_BITSPERSAMPLE, bitspersample);
-    TIFFSetField(tifP, TIFFTAG_ORIENTATION,   ORIENTATION_TOPLEFT);
-    TIFFSetField(tifP, TIFFTAG_COMPRESSION,   cmdline.compression);
-    if (cmdline.compression == COMPRESSION_CCITTFAX3 && cmdline.g3options != 0)
-        TIFFSetField( tifP, TIFFTAG_GROUP3OPTIONS, cmdline.g3options );
-    if (cmdline.compression == COMPRESSION_LZW && cmdline.predictor != -1)
-        TIFFSetField( tifP, TIFFTAG_PREDICTOR, cmdline.predictor);
-    TIFFSetField(tifP, TIFFTAG_PHOTOMETRIC,      photometric);
-    TIFFSetField(tifP, TIFFTAG_FILLORDER,        cmdline.fillorder);
-    TIFFSetField(tifP, TIFFTAG_DOCUMENTNAME,     inputFileDescription);
-    TIFFSetField(tifP, TIFFTAG_IMAGEDESCRIPTION, "converted PNM file");
-    TIFFSetField(tifP, TIFFTAG_SAMPLESPERPIXEL,  samplesperpixel);
-    TIFFSetField(tifP, TIFFTAG_ROWSPERSTRIP,     rowsperstrip);
-    if (cmdline.xresolution != -1)
-        TIFFSetField(tifP, TIFFTAG_XRESOLUTION, cmdline.xresolution);
-    if (cmdline.yresolution != -1)
-        TIFFSetField(tifP, TIFFTAG_YRESOLUTION, cmdline.yresolution);
-    TIFFSetField(tifP, TIFFTAG_RESOLUTIONUNIT,   cmdline.resolutionUnit);
-    /* TIFFSetField(tifP, TIFFTAG_STRIPBYTECOUNTS,
-       pam.height / rowsperstrip); */
-    TIFFSetField(tifP, TIFFTAG_PLANARCONFIG,     PLANARCONFIG_CONTIG);
-
     if (!chv) {
         cht = NULL;
         tiffColorMap = NULL;
     } else {
         createTiffColorMap(&pam, bitspersample, chv, colors, &tiffColorMap);
 
-        TIFFSetField(tifP, TIFFTAG_COLORMAP,
-                     tiffColorMap[PAM_RED_PLANE],
-                     tiffColorMap[PAM_GRN_PLANE],
-                     tiffColorMap[PAM_BLU_PLANE]);
-
         /* Convert color vector to color hash table, for fast lookup. */
         cht = pnm_computetupletablehash(&pam, chv, colors);
         pnm_freetupletable(&pam, chv);
     }
 
+    setTiffFields(tifP, cmdline, &pam, bitspersample, photometric,
+                  samplesperpixel, tiffColorMap, inputFileDescription,
+                  cmdline.taglist);
+
     writeScanLines(&pam, tifP, cht,
                    tiff_maxval, bitspersample, photometric, bytesperrow, 
-                   grayscale, cmdline.fillorder);
+                   cmdline.fillorder);
 
     if (tiffColorMap)
         destroyTiffColorMap(&pam, tiffColorMap);
