@@ -152,7 +152,7 @@ static void
 init_hilbert(int const w, 
              int const h) {
 /*----------------------------------------------------------------------------
-  Initialise the Hilbert curve tracer 
+  Initialize the Hilbert curve tracer 
 -----------------------------------------------------------------------------*/
     int big,ber;
     hil_width = w;
@@ -575,12 +575,12 @@ clusterConvertRow(struct converter * const converterP,
                   bit                      bitrow[]) {
 
     struct clusterState * const stateP = converterP->stateP;
-    unsigned int const diameter = 2 * stateP->radius;
+    unsigned int const radius = stateP->radius;
 
     unsigned int col;
 
     for (col = 0; col < converterP->cols; ++col)
-        if (grayrow[col] > stateP->clusterMatrix[row % diameter][col % diameter])
+        if (grayrow[col] > stateP->clusterMatrix[row % radius][col % radius])
             bitrow[col] = PBM_WHITE;
         else
             bitrow[col] = PBM_BLACK;
@@ -592,11 +592,10 @@ static void
 clusterDestroy(struct converter * const converterP) {
 
     struct clusterState * const stateP = converterP->stateP;
-    unsigned int const diameter = 2 * stateP->radius;
 
     unsigned int row;
 
-    for (row = 0; row < diameter; ++row)
+    for (row = 0; row < stateP->radius; ++row)
         free(stateP->clusterMatrix[row]);
 
     free(stateP->clusterMatrix);
@@ -612,7 +611,6 @@ createClusterConverter(unsigned int const radius,
                        gray         const maxval) {
     
     int const clusterNormalizer = radius * radius * 2;
-    unsigned int const diameter = 2 * radius;
 
     struct converter converter;
     struct clusterState * stateP;
@@ -626,13 +624,13 @@ createClusterConverter(unsigned int const radius,
 
     stateP->radius = radius;
 
-    MALLOCARRAY_NOFAIL(stateP->clusterMatrix, diameter);
-    for (row = 0; row < diameter; ++row) {
+    MALLOCARRAY_NOFAIL(stateP->clusterMatrix, radius);
+    for (row = 0; row < radius; ++row) {
         unsigned int col;
 
-        MALLOCARRAY_NOFAIL(stateP->clusterMatrix[row], diameter);
+        MALLOCARRAY_NOFAIL(stateP->clusterMatrix[row], radius);
         
-        for (col = 0; col < diameter; ++col) {
+        for (col = 0; col < radius; ++col) {
             int val;
             switch (radius) {
             case 3: val = cluster3[row][col]; break;
