@@ -5,7 +5,7 @@
    We produce two main kinds of Postscript program:
 
       1) Use built in Postscript filters /ASCII85Decode, /ASCIIHexDecode,
-         /RunLengthDecode, and /FlateDecode; and
+         /RunLengthDecode, and /FlateDecode;
 
          We use methods we learned from Dirk Krause's program Bmeps and
          raster encoding code copied almost directly from Bmeps.
@@ -74,9 +74,9 @@ static bool verbose;
 
 
 static void
-parse_dpi(const char *   const dpiOpt, 
-          unsigned int * const dpiXP, 
-          unsigned int * const dpiYP) {
+parseDpi(const char *   const dpiOpt, 
+         unsigned int * const dpiXP, 
+         unsigned int * const dpiYP) {
 
     char *dpistr2;
     unsigned int dpiX, dpiY;
@@ -174,7 +174,7 @@ parseCommandLine(int argc, char ** argv,
         pm_error("You cannot specify both -setpage and -nosetpage");
 
     if (dpiSpec)
-        parse_dpi(dpiOpt, &cmdlineP->dpiX, &cmdlineP->dpiY);
+        parseDpi(dpiOpt, &cmdlineP->dpiX, &cmdlineP->dpiY);
     else {
         cmdlineP->dpiX = 300;
         cmdlineP->dpiY = 300;
@@ -698,9 +698,11 @@ setupReadstringPsFilter(bool         const rle,
 
    The statements set /picstr and /inputf.
 -----------------------------------------------------------------------------*/
-    printf("/picstr\n  %u string\ndef\n", color ? 3 * width : width);
+    printf("/picstr\n  %u string\n", color ? 3 * width : width);
+    printf("def\n");
     
-    printf("/inputf\n  currentfile\n");
+    printf("/inputf\n");
+    printf("  currentfile\n");
     if (ascii85)
         printf("  /ASCII85Decode filter\n");
     else 
@@ -762,8 +764,8 @@ defineReadstring(bool const rle) {
 
 
 static void
-setupReadstringNative(bool const rle,
-                      bool const color,
+setupReadstringNative(bool         const rle,
+                      bool         const color,
                       unsigned int const icols, 
                       unsigned int const padright, 
                       unsigned int const bps) {
@@ -846,7 +848,6 @@ putinit(unsigned int const postscriptLevel,
         (int) llx, (int) lly,
         (int) (llx + scols + 0.5), (int) (lly + srows + 0.5));
     printf("%%%%EndComments\n");
-    printf("%%%%Page: Image0 1\n");
 
     if (dict)
         printf("4 dict begin\n");
