@@ -83,10 +83,10 @@ struct cmdlineInfo {
     /* All the information the user supplied in the command line,
        in a form easy for the program to use.
     */
-    char *inputFilename;
+    char * inputFilename;
     unsigned int headerdump;
-    char *alphaFilename;
-    int alphaStdout;
+    char * alphaFilename;
+    bool alphaStdout;
     unsigned int respectfillorder;   /* -respectfillorder option */
     unsigned int byrow;
     unsigned int verbose;
@@ -96,7 +96,7 @@ struct cmdlineInfo {
 
 static void
 parseCommandLine(int argc, char ** argv,
-                 struct cmdlineInfo *cmdlineP) {
+                 struct cmdlineInfo * const cmdlineP) {
 /*----------------------------------------------------------------------------
    Note that many of the strings that this function returns in the
    *cmdlineP structure are actually in the supplied argv array.  And
@@ -106,7 +106,7 @@ parseCommandLine(int argc, char ** argv,
     optStruct3 opt;
     optEntry *option_def;
     unsigned int option_def_index;
-    unsigned int alpha_spec;
+    unsigned int alphaSpec;
 
     MALLOCARRAY_NOFAIL(option_def, 100);
 
@@ -124,7 +124,7 @@ parseCommandLine(int argc, char ** argv,
     OPTENT3('h', "headerdump", 
             OPT_FLAG,   NULL, &cmdlineP->headerdump,           0);
     OPTENT3(0,   "alphaout",   
-            OPT_STRING, &cmdlineP->alphaFilename, &alpha_spec, 0);
+            OPT_STRING, &cmdlineP->alphaFilename, &alphaSpec,  0);
 
     optParseOptions3(&argc, argv, opt, sizeof(opt), 0);
 
@@ -136,10 +136,15 @@ parseCommandLine(int argc, char ** argv,
         pm_error("Too many arguments.  The only argument accepted "
                  "is the input file name");
 
-    if (alpha_spec && STREQ(cmdlineP->alphaFilename, "-"))
-        cmdlineP->alphaStdout = 1;
-    else 
-        cmdlineP->alphaStdout = 0;
+    if (alphaSpec) {
+        if (STREQ(cmdlineP->alphaFilename, "-"))
+            cmdlineP->alphaStdout = TRUE;
+        else
+            cmdlineP->alphaStdout = FALSE;
+    } else {
+        cmdlineP->alphaFilename = NULL;
+        cmdlineP->alphaStdout = FALSE;
+    }
 }
 
 
@@ -1010,8 +1015,9 @@ int
 main(int argc, char * argv[]) {
 
     struct cmdlineInfo cmdline;
-    TIFF* tif;
-    FILE *alphaFile, *imageoutFile;
+    TIFF * tif;
+    FILE * alphaFile;
+    FILE * imageoutFile;
 
     pnm_init( &argc, argv );
 
