@@ -1,4 +1,4 @@
-/* xwdtopnm.c - read an X11 or X10 window dump file and write a portable anymap
+/* xwdtopnm.c - read an X11 or X10 window dump file and write a PNM image.
 **
 ** Copyright (C) 1989, 1991 by Jef Poskanzer.
 **
@@ -22,14 +22,17 @@
 
 #include <stdio.h>
 #include <string.h>
-#include "pnm.h"
-#include "x10wd.h"
-#include "x11wd.h"
+#include <assert.h>
+
+#include "pm_c_util.h"
 #include "shhopt.h"
 #include "mallocvar.h"
 #include "nstring.h"
+#include "pnm.h"
+#include "x10wd.h"
+#include "x11wd.h"
 
-static struct cmdline_info {
+struct cmdlineInfo {
     /* All the information the user supplied in the command line,
        in a form easy for the program to use.
     */
@@ -37,7 +40,7 @@ static struct cmdline_info {
     unsigned int verbose;
     unsigned int debug;
     unsigned int headerdump;
-} cmdline;
+};
 
 
 static bool debug;
@@ -47,43 +50,6 @@ static bool verbose;
 static unsigned int pixel_count = 0;
 #endif
 
-struct row_control {
-    /* This structure contains the state of the getpix() reader as it
-       reads across a row in the input image.
-       */
-    union {
-        /* The current item (the item most recently read from the
-           image file.  Meaningless if 'bits_left' == 0.
-           
-           Which of the members applies depends on the bits per item of
-           the input image.  
-        */
-        long l;    /* 32 bits per item */
-        short s;   /* 16 bits per item */
-        char c;    /*  8 bits per item */
-    } item;
-    int bits_used;
-      /* This is the number of bits in the current item that have already
-         been returned as part of a pixel for a previous call or saved
-         as carryover_bits for use in a future call.
-         */
-    int bits_left;
-      /* This is the number of bits in the current item that have not yet
-         been returned as part of a pixel or saved as carryover bits.
-         */
-    unsigned long carryover_bits;
-      /* This is the odd bits left over from one item that need to be
-         combined with more bits from the next item to form a pixel
-         value (the pixel is split between two items).  An item is a
-         unit of data read from the image file.  
-
-         It is a 32 bit bitstring with the carryover bits right-justified
-         in it.  
-      */
-    int bits_carried_over;
-      /* This is the number of carryover bits in 'carryover_bits' */
-};
-
 /* Byte-swapping junk. */
 
 union cheat {
@@ -162,20 +128,22 @@ one_bits(const unsigned long input) {
 
 static void
 parseCommandLine(int argc, char ** argv,
-                 struct cmdline_info *cmdlineP) {
+                 struct cmdlineInfo * const cmdlineP) {
 /*----------------------------------------------------------------------------
    Note that many of the strings that this function returns in the
    *cmdline_p structure are actually in the supplied argv array.  And
    sometimes, one of these strings is actually just a suffix of an entry
    in argv!
 -----------------------------------------------------------------------------*/
-    optEntry *option_def = malloc(100*sizeof(optEntry));
+    optEntry * option_def;
         /* Instructions to OptParseOptions3 on how to parse our options.
          */
     optStruct3 opt;
 
     unsigned int option_def_index;
 
+    MALLOCARRAY(option_def, 100);
+
     option_def_index = 0;   /* incremented by OPTENTRY */
 
     OPTENT3(0,   "verbose",    OPT_FLAG,   NULL, &cmdlineP->verbose,       0);
@@ -339,31 +307,31 @@ fixH11ByteOrder(X11WDFileHeader *  const h11P,
     if (h11P->file_version == X11WD_FILE_VERSION) {
         memcpy(h11FixedP, h11P, sizeof(*h11FixedP));
     } else {
-        h11FixedP->header_size = bs_long( h11P->header_size );
-        h11FixedP->file_version = bs_long( h11P->file_version );
-        h11FixedP->pixmap_format = bs_long( h11P->pixmap_format );
-        h11FixedP->pixmap_depth = bs_long( h11P->pixmap_depth );
-        h11FixedP->pixmap_width = bs_long( h11P->pixmap_width );
-        h11FixedP->pixmap_height = bs_long( h11P->pixmap_height );
-        h11FixedP->xoffset = bs_long( h11P->xoffset );
-        h11FixedP->byte_order = bs_long( h11P->byte_order );
-        h11FixedP->bitmap_unit = bs_long( h11P->bitmap_unit );
-        h11FixedP->bitmap_bit_order = bs_long( h11P->bitmap_bit_order );
-        h11FixedP->bitmap_pad = bs_long( h11P->bitmap_pad );
-        h11FixedP->bits_per_pixel = bs_long( h11P->bits_per_pixel );
-        h11FixedP->bytes_per_line = bs_long( h11P->bytes_per_line );
-        h11FixedP->visual_class = bs_long( h11P->visual_class );
-        h11FixedP->red_mask = bs_long( h11P->red_mask );
-        h11FixedP->green_mask = bs_long( h11P->green_mask );
-        h11FixedP->blue_mask = bs_long( h11P->blue_mask );
-        h11FixedP->bits_per_rgb = bs_long( h11P->bits_per_rgb );
-        h11FixedP->colormap_entries = bs_long( h11P->colormap_entries );
-        h11FixedP->ncolors = bs_long( h11P->ncolors );
-        h11FixedP->window_width = bs_long( h11P->window_width );
-        h11FixedP->window_height = bs_long( h11P->window_height );
-        h11FixedP->window_x = bs_long( h11P->window_x );
-        h11FixedP->window_y = bs_long( h11P->window_y );
-        h11FixedP->window_bdrwidth = bs_long( h11P->window_bdrwidth );
+        h11FixedP->header_size = bs_long(h11P->header_size);
+        h11FixedP->file_version = bs_long(h11P->file_version);
+        h11FixedP->pixmap_format = bs_long(h11P->pixmap_format);
+        h11FixedP->pixmap_depth = bs_long(h11P->pixmap_depth);
+        h11FixedP->pixmap_width = bs_long(h11P->pixmap_width);
+        h11FixedP->pixmap_height = bs_long(h11P->pixmap_height);
+        h11FixedP->xoffset = bs_long(h11P->xoffset);
+        h11FixedP->byte_order = bs_long(h11P->byte_order);
+        h11FixedP->bitmap_unit = bs_long(h11P->bitmap_unit);
+        h11FixedP->bitmap_bit_order = bs_long(h11P->bitmap_bit_order);
+        h11FixedP->bitmap_pad = bs_long(h11P->bitmap_pad);
+        h11FixedP->bits_per_pixel = bs_long(h11P->bits_per_pixel);
+        h11FixedP->bytes_per_line = bs_long(h11P->bytes_per_line);
+        h11FixedP->visual_class = bs_long(h11P->visual_class);
+        h11FixedP->red_mask = bs_long(h11P->red_mask);
+        h11FixedP->green_mask = bs_long(h11P->green_mask);
+        h11FixedP->blue_mask = bs_long(h11P->blue_mask);
+        h11FixedP->bits_per_rgb = bs_long(h11P->bits_per_rgb);
+        h11FixedP->colormap_entries = bs_long(h11P->colormap_entries);
+        h11FixedP->ncolors = bs_long(h11P->ncolors);
+        h11FixedP->window_width = bs_long(h11P->window_width);
+        h11FixedP->window_height = bs_long(h11P->window_height);
+        h11FixedP->window_x = bs_long(h11P->window_x);
+        h11FixedP->window_y = bs_long(h11P->window_y);
+        h11FixedP->window_bdrwidth = bs_long(h11P->window_bdrwidth);
     }
     *h11FixedPP = h11FixedP;
 }
@@ -376,14 +344,14 @@ readX11Colormap(FILE *      const file,
                 bool        const byteSwap,
                 X11XColor** const x11colorsP) {
                 
-    X11XColor* x11colors;
+    X11XColor * x11colors;
     int rc;
 
     /* Read X11 colormap. */
     MALLOCARRAY(x11colors, ncolors);
     if (x11colors == NULL)
         pm_error("out of memory");
-    rc = fread(x11colors, sizeof(X11XColor), ncolors, file);
+    rc = fread(x11colors, sizeof(x11colors[0]), ncolors, file);
     if (rc != ncolors)
         pm_error("couldn't read X11 XWD colormap");
     if (byteSwap) {
@@ -524,7 +492,7 @@ processX11Header(X11WDFileHeader *  const h11P,
     fixH11ByteOrder(h11P, &h11FixedP);
 
     if (byte_swap && verbose)
-        pm_message("Input is different endianness from this machine.");
+        pm_message("Header is different endianness from this machine.");
     
     for (i = 0; i < h11FixedP->header_size - sizeof(*h11FixedP); ++i)
         if (getc(file) == EOF)
@@ -640,10 +608,6 @@ processX11Header(X11WDFileHeader *  const h11P,
        has to be the item size.  
     */
     *bits_per_itemP = MAX(h11FixedP->bitmap_pad, h11FixedP->bitmap_unit);
-    if (h11FixedP->bits_per_pixel > *bits_per_itemP)
-        pm_error("Invalid xwd.  bits per pixel (%u) is greater than the "
-                 "bits per item (%u)", 
-                 h11FixedP->bits_per_pixel, *bits_per_itemP);
 
     *bits_per_pixelP = h11FixedP->bits_per_pixel;
 
@@ -659,7 +623,7 @@ processX11Header(X11WDFileHeader *  const h11P,
 
 
 static void
-getinit(FILE *             const file, 
+getinit(FILE *             const ifP, 
         int *              const colsP, 
         int *              const rowsP, 
         int *              const padrightP, 
@@ -675,7 +639,17 @@ getinit(FILE *             const file,
         enum byteorder *   const byte_orderP,
         enum byteorder *   const bit_orderP,
         bool               const headerDump) {
+/*----------------------------------------------------------------------------
+   Read the header from the XWD image in input stream 'ifP'.  Leave
+   the stream positioned to the beginning of the raster.
 
+   Return various fields from the header.
+
+   Return as *padrightP the number of additional pixels of padding are
+   at the end of each line of input.  This says the input stream
+   contains *colsP pixels of image data plus *padrightP pixels of
+   padding.
+-----------------------------------------------------------------------------*/
     /* Assume X11 headers are larger than X10 ones. */
     unsigned char header[sizeof(X11WDFileHeader)];
     X10WDFileHeader* h10P;
@@ -696,7 +670,7 @@ getinit(FILE *             const file,
        error.  
     */
 
-    rc = fread(&header[0], sizeof(*h10P), 1, file);
+    rc = fread(&header[0], sizeof(*h10P), 1, ifP);
     if (rc != 1)
         pm_error( "couldn't read XWD file header" );
 
@@ -705,7 +679,7 @@ getinit(FILE *             const file,
         
         if (verbose)
             pm_message("Input is X10");
-        processX10Header(h10P, file, colsP, rowsP, padrightP, maxvalP, 
+        processX10Header(h10P, ifP, colsP, rowsP, padrightP, maxvalP, 
                          visualclassP, formatP, 
                          colorsP, bits_per_pixelP, bits_per_itemP, 
                          red_maskP, green_maskP, blue_maskP, 
@@ -720,14 +694,14 @@ getinit(FILE *             const file,
 
         /* Read the balance of the X11 header */
         rc = fread(&header[sizeof(*h10P)], 
-                   sizeof(*h11P) - sizeof(*h10P), 1, file);
+                   sizeof(*h11P) - sizeof(*h10P), 1, ifP);
         if (rc != 1)
             pm_error("couldn't read end of X11 XWD file header");
 
         if (headerDump)
             dumpX11Header(h11P);
 
-        processX11Header(h11P, file, colsP, rowsP, padrightP, maxvalP, 
+        processX11Header(h11P, ifP, colsP, rowsP, padrightP, maxvalP, 
                          visualclassP, formatP, 
                          colorsP, bits_per_pixelP, bits_per_itemP, 
                          red_maskP, green_maskP, blue_maskP, 
@@ -776,16 +750,167 @@ getinit(FILE *             const file,
 #endif
 
 
+
+/*----------------------------------------------------------------------------
+   The pixel reader.
+
+   The pixel reader is an object that reads an XWD raster and gives you
+   one pixel at a time from it.
+
+   It consists of a structure of type 'pixelReader' and the
+   getpix() and pixelReaderInit() subroutines.
+-----------------------------------------------------------------------------*/
+
+typedef struct {
+    /* This structure contains the state of the getpix() reader as it
+       reads across a row in the input image.
+       */
+    FILE * fileP;
+    unsigned long itemBuffer;
+        /* The item buffer.  This contains what's left of the item
+           most recently read from the image file -- an item goes from the
+           XWD raster into here and then bits disappear from it as they
+           become part of pixels returned by the object.
+
+           'nBitsLeft' tells how many bits are in the buffer now.  It's
+           zero when nothing has ever been read from the file.  Only
+           the least signficant 'nBitsLeft' bits are meaningful.
+
+           The numeric value of the member is the number whose pure
+           binary representation is the bit string in the buffer.
+
+           That bit string starts out as the contents of one item of
+           the XWD raster, with the "byte order" value from the XWD
+           header applied.  E.g. Assume bits per item is 16 and the
+           and the "byte order" value is "MSB First".  Assume the
+           raster contains 0x01 at Offset 109 and 0x02 at Offset 110.
+           The value of this member just after that item is read is
+           two hundred fifty-eight.  If we are running on a
+           little-endian machine, it appears in memory as 0x02 at
+           Address A and 0x01 at Address A+1.
+
+           Then we pull bits from either the beginning or end of the
+           buffer according to the "bit order" value from the XWD
+           header.  E.g. in the example above, assume "bit order" is
+           lsb first.  and bits per pixel is 4.  After reading the
+           first pixel (0010b) from the buffer, 'itemBuffer' is
+           sixteen (0x010) and 'nBitsLeft' is 12.
+        */
+    unsigned int nBitsLeft;
+      /* This is the number of bits in the current item that have not yet
+         been returned as part of a pixel.
+      */
+    int bitsPerPixel;
+    int bitsPerItem;
+    enum byteorder byteOrder;
+    enum byteorder bitOrder;
+} pixelReader;
+
+
+
+static void
+pixelReaderInit(pixelReader *  const pixelReaderP,
+                FILE *         const fileP,
+                int            const bitsPerPixel,
+                int            const bitsPerItem, 
+                enum byteorder const byteOrder,
+                enum byteorder const bitOrder) {
+    
+    pixelReaderP->fileP           = fileP;
+    pixelReaderP->bitsPerPixel    = bitsPerPixel;
+    pixelReaderP->bitsPerItem     = bitsPerItem;
+    pixelReaderP->byteOrder       = byteOrder;
+    pixelReaderP->bitOrder        = bitOrder;
+
+    pixelReaderP->nBitsLeft       = 0;
+}    
+
+
+
+static void
+readItem(pixelReader * const rdrP) {
+/*----------------------------------------------------------------------------
+   Read one item from the XWD raster associated with pixel reader *rdrP.
+
+   Put the item into the item buffer of the pixel reader object *rdrP
+   with the results.
+-----------------------------------------------------------------------------*/
+    assert(rdrP->nBitsLeft == 0);
+
+    switch (rdrP->bitsPerItem) {
+    case 8: {
+        unsigned char const item8 = getc(rdrP->fileP);
+        rdrP->itemBuffer = item8;
+        rdrP->nBitsLeft = 8;
+    }
+        break;
+
+    case 16: {
+        short item16;
+
+        switch (rdrP->byteOrder) {
+        case MSBFirst:
+            pm_readbigshort(rdrP->fileP, &item16);
+            break;
+        case LSBFirst:
+            pm_readlittleshort(rdrP->fileP, &item16);
+            break;
+        }
+        rdrP->itemBuffer = (unsigned short)item16;
+        rdrP->nBitsLeft = 16;
+    }
+        break;
+        
+    case 32: {
+        long item32;
+        
+        switch (rdrP->byteOrder) {
+        case MSBFirst:
+            pm_readbiglong(rdrP->fileP, &item32);
+            break;
+        case LSBFirst:
+            pm_readlittlelong(rdrP->fileP, &item32);
+            break;
+        }
+        rdrP->itemBuffer = item32;
+        rdrP->nBitsLeft = 32;
+    }
+        break;
+    default:
+        pm_error("INTERNAL ERROR: impossible bits_per_item");
+    }
+}
+
+
+
+static unsigned long const lsbmask[] = {
+/*----------------------------------------------------------------------------
+   lsbmask[i] is the mask you use to select the i least signficant bits
+   of a bit string.
+-----------------------------------------------------------------------------*/
+    0x00000000,
+    0x00000001, 0x00000003, 0x00000007, 0x0000000f, 
+    0x0000001f, 0x0000003f, 0x0000007f, 0x000000ff,
+    0x000001ff, 0x000003ff, 0x000007ff, 0x00000fff,
+    0x00001fff, 0x00003fff, 0x00007fff, 0x0000ffff,
+    0x0001ffff, 0x0003ffff, 0x0007ffff, 0x000fffff,
+    0x001fffff, 0x003fffff, 0x007fffff, 0x00ffffff,
+    0x01ffffff, 0x03ffffff, 0x07ffffff, 0x0fffffff,
+    0x1fffffff, 0x3fffffff, 0x7fffffff, 0xffffffff
+};
+
+
 static unsigned long
-getpix(FILE *file, struct row_control * const row_controlP,
-       const int bits_per_pixel, const int bits_per_item, 
-       const enum byteorder byte_order, const enum byteorder bit_order) {
+getpix(pixelReader * const rdrP) {
 /*----------------------------------------------------------------------------
    Get a pixel from the input image.
 
    A pixel is a bit string.  It may be either an rgb triplet or an index
    into the colormap (or even an rgb triplet of indices into the colormaps!).
    We don't care -- it's just a bit string.
+
+   We return an integer.  It's the integer that the pixel represents as
+   pure binary cipher, with the first bit the most significant bit.
    
    The basic unit of storage in the input file is an "item."  An item
    can be 1, 2, or 4 bytes, and 'bits_per_item' tells us which.  Each
@@ -800,165 +925,79 @@ getpix(FILE *file, struct row_control * const row_controlP,
    may be arranged from left to right or right to left.  'bit_order' tells
    us which.
 
-   But it's not that simple.  Each individual row contains an integral
-   number of items.  This means the last item in the row may contain
-   padding bits.  The padding is on the right or left, according to
-   'bit_order'.
+   But it's not that simple.  Sometimes dummy pixels are added to the
+   right edge of the image in order to make an integral number of
+   items in each row of the raster.  getpix() doesn't know anything
+   about that, though -- it gets the dummy pixels the same as any
+   other pixel.  (This program is written as if it is always whole
+   pixels that get added for padding, but I wonder.  When pixels are 3
+   or 4 bytes and items are 4 bytes, sub-pixel padding would make
+   sense.  But then, maybe in formats with 3 or 4 bytes pixels,
+   there's never padding.  That seems to be the case so far...).  The
+   XWD header has a field that tells how many bytes there are per XWD
+   raster line, so that's the final word on how much padding there is.
    
    The most difficult part of getting the pixel is the ones that span
    items.  We detect when an item has part, but not all, of the next
-   pixel in it and store the fragment as "carryover" bits for use in the
-   next call to this function.
+   pixel (after the one we return) in it and store the fragment as
+   "carryover" bits for use in the next call to this function.
 
    All this state information (carryover bits, etc.) is kept in 
    *row_controlP.
 
 -----------------------------------------------------------------------------*/
     unsigned long pixel;
-      /* This is the pixel value we ultimately return.  It is a 32 bit
-         bitstring, with the pixel value right-justified in it.
-         */
-
-    int bits_to_take;
-      /* This is the number of bits we need to take from the current
-         item to combine with carryover bits to form a pixel.
-         */
-    DEBUG_PIXEL_1;
-
-    if (row_controlP->bits_left <= 0) {
-        /* We've used up the most recently read item.  Get the next one
-           from the input file.
+        /* Accumulator for the value we ultimately return.  We shift in
+           bits from the right end.  The number of bits presently in the
+           accumulator is rdrP->bitsPerPixel - bitsStillNeeded .
         */
-        switch (bits_per_item) {
-        case 8:
-            row_controlP->item.c = getc(file);
-            break;
-
-        case 16:
-            switch (byte_order) {
-            case MSBFirst:
-                pm_readbigshort(file, &row_controlP->item.s);
-                break;
-            case LSBFirst:
-                pm_readlittleshort(file, &row_controlP->item.s);
-                break;
-            }
-            break;
-
-        case 32:
-            switch (byte_order) {
-            case MSBFirst:
-                pm_readbiglong(file, &row_controlP->item.l);
-                break;
-            case LSBFirst:
-                pm_readlittlelong(file, &row_controlP->item.l);
-                break;
-            }
-            break;
-
-        default:
-            pm_error("INTERNAL ERROR: impossible bits_per_item");
-        }
-        DEBUG_PIXEL_2;
-
-        row_controlP->bits_used = 0;  
-          /* Fresh item from file; none of it used yet. */
-        row_controlP->bits_left = bits_per_item;
-    }
     
-    bits_to_take = bits_per_pixel - row_controlP->bits_carried_over;
+    unsigned int nBitsStillNeeded;
+        /* How many bits we still need to add to 'pixel',
+           as we build it up to the
+           full amount we have to return.  The bits are right justified in
+           it -- additional bits will shift in from the right.
+        */
 
-    { 
-        unsigned long bits_to_take_mask;
-        static unsigned long bits_taken;
-          /* The bits we took from the current item:  'bits_to_take' bits
-             right-justified in a 32 bit bitstring.
-          */
-        int bit_shift;
-          /* How far to shift item to get the bits we're taking
-             right-justified 
-          */
+    assert(rdrP->bitsPerPixel <= 32);
 
-        if (bit_order == MSBFirst)
-            bit_shift = row_controlP->bits_left - bits_to_take;
-        else
-            bit_shift = row_controlP->bits_used;
+    pixel = 0;
+    nBitsStillNeeded = rdrP->bitsPerPixel;
 
-        if ( bits_to_take == sizeof(bits_to_take_mask) * 8 )
-            bits_to_take_mask = -1;
-        else
-            bits_to_take_mask = ( 1 << bits_to_take ) - 1;
-        
-        switch ( bits_per_item ) {
-        case 8:
-            bits_taken = (row_controlP->item.c >> bit_shift) 
-                & bits_to_take_mask;
-            break;
-        case 16:
-            bits_taken = (row_controlP->item.s >> bit_shift) 
-                & bits_to_take_mask;
-            break;
-        case 32:
-            bits_taken = (row_controlP->item.l >> bit_shift) 
-                & bits_to_take_mask;
-            break;
+    while (nBitsStillNeeded > 0) {
+        if (rdrP->nBitsLeft == 0)
+            /* Buffer's empty.  Have to go back to the well for
+               rdrP->bitsPerItem more bits.
+            */
+            readItem(rdrP);
+
+        {
+            unsigned int const nBitsToTake =
+                MIN(rdrP->nBitsLeft, nBitsStillNeeded);
+            unsigned long const bitsToTakeMask = lsbmask[nBitsToTake];
+                /* E.g. if nbitsToTake is 4, this is 0x0000000F */
+
+            unsigned long bitsToTake;
+
+            assert(nBitsToTake <= 32);
+            
+            if (rdrP->bitOrder == MSBFirst) {
+                unsigned int const nBitsToLeave =
+                    rdrP->nBitsLeft - nBitsToTake;
+                bitsToTake =
+                    (rdrP->itemBuffer >> nBitsToLeave) & bitsToTakeMask;
+            } else {
+                bitsToTake = rdrP->itemBuffer & bitsToTakeMask;
+                bitsToTake >>= nBitsToTake;
+            }                
+            /* Shift the bits into the right end of the accumulator */
+            pixel <<= nBitsToTake;
+            pixel |= bitsToTake;
+
+            rdrP->nBitsLeft -= nBitsToTake;
+            nBitsStillNeeded -= nBitsToTake;
         }
-
-        /* Now combine any carried over bits with the bits just taken */
-        if (bit_order == MSBFirst)
-            pixel = bits_taken | row_controlP->carryover_bits << bits_to_take;
-        else
-            pixel = bits_taken << row_controlP->bits_carried_over |
-                row_controlP->carryover_bits;
-
-        DEBUG_PIXEL_3;
     }
-
-    row_controlP->bits_used += bits_to_take;
-    row_controlP->bits_left -= bits_to_take;
-
-    if (row_controlP->bits_left > 0 && 
-        row_controlP->bits_left < bits_per_pixel) {
-        /* Part, but not all, of the next pixel is in this item. Get it
-           into carryover_bits and then mark this item all used up.
-           */
-        unsigned long bits_left_mask;
-        int bit_shift;
-           /* How far to shift item to get the bits that are left
-              right-justified 
-           */
-        if ( row_controlP->bits_left == sizeof(bits_left_mask) * 8 )
-            bits_left_mask = -1;  /* All one bits */
-        else
-            bits_left_mask = ( 1 << row_controlP->bits_left ) - 1;
-
-        if (bit_order == MSBFirst)
-            bit_shift = 0;
-        else
-            bit_shift = row_controlP->bits_used;
-
-        switch ( bits_per_item ) {
-        case 8:
-            row_controlP->carryover_bits = 
-                (row_controlP->item.c >> bit_shift) & bits_left_mask;
-            break;
-        case 16:
-            row_controlP->carryover_bits = 
-                (row_controlP->item.s >> bit_shift) & bits_left_mask;
-            break;
-        case 32:
-            row_controlP->carryover_bits = 
-                (row_controlP->item.l >> bit_shift) & bits_left_mask;
-            break;
-        }
-        row_controlP->bits_carried_over = row_controlP->bits_left;
-        row_controlP->bits_used = bits_per_item;
-        row_controlP->bits_left = 0;
-    } else {
-        row_controlP->carryover_bits = 0;
-        row_controlP->bits_carried_over = 0;
-    }
-    DEBUG_PIXEL_4;
     return pixel;
 }
 
@@ -1017,53 +1056,39 @@ reportInfo(int              const cols,
 
 
 static void 
-convertSimpleIndex(FILE *               const ifp,
-                   int                  const cols,
-                   struct row_control * const row_controlP,
-                   const xel *          const colors,
-                   int                  const bits_per_pixel,
-                   int                  const bits_per_item,
-                   enum byteorder       const byte_order,
-                   enum byteorder       const bit_order,
-                   xel *                const xelrow) {
+convertRowSimpleIndex(pixelReader *  const pixelReaderP,
+                      int            const cols,
+                      const xel *    const colors,
+                      xel *          const xelrow) {
     
     unsigned int col;
     for (col = 0; col < cols; ++col)
-        xelrow[col] = colors[getpix( ifp, row_controlP, 
-                                     bits_per_pixel, bits_per_item, 
-                                     byte_order, bit_order)];
+        xelrow[col] = colors[getpix(pixelReaderP)];
 }
 
 
 
 static void
-convertDirect(FILE *               const ifp,
-              int                  const cols,
-              struct row_control * const row_controlP,
-              const xel *          const colors,
-              int                  const bits_per_pixel,
-              int                  const bits_per_item,
-              enum byteorder       const byte_order,
-              enum byteorder       const bit_order,
-              unsigned long        const red_mask,
-              unsigned long        const grn_mask,
-              unsigned long        const blu_mask,
-              xel *                const xelrow) {
+convertRowDirect(pixelReader *  const pixelReaderP,
+                 int            const cols,
+                 const xel *    const colors,
+                 unsigned long  const red_mask,
+                 unsigned long  const grn_mask,
+                 unsigned long  const blu_mask,
+                 xel *          const xelrow) {
         
     unsigned int col;
 
     for (col = 0; col < cols; ++col) {
         unsigned long pixel;
-        /* This is a triplet of indices into the color map, packed
-           into this bit string according to red_mask, etc.
-        */
+            /* This is a triplet of indices into the color map, packed
+               into this bit string according to red_mask, etc.
+            */
         unsigned int red_index, grn_index, blu_index;
-        /* These are indices into the color map, unpacked from 'pixel'.
-         */
+            /* These are indices into the color map, unpacked from 'pixel'.
+             */
             
-        pixel = getpix(ifp, row_controlP, 
-                       bits_per_pixel, bits_per_item, 
-                       byte_order, bit_order);
+        pixel = getpix(pixelReaderP);
 
         red_index = (pixel & red_mask) >> zero_bits(red_mask);
         grn_index = (pixel & grn_mask) >> zero_bits(grn_mask); 
@@ -1080,19 +1105,14 @@ convertDirect(FILE *               const ifp,
 
 
 static void
-convertTrueColor(FILE *               const ifp,
-                 int                  const cols,
-                 pixval               const maxval,
-                 struct row_control * const row_controlP,
-                 const xel *          const colors,
-                 int                  const bits_per_pixel,
-                 int                  const bits_per_item,
-                 enum byteorder       const byte_order,
-                 enum byteorder       const bit_order,
-                 unsigned long        const red_mask,
-                 unsigned long        const grn_mask,
-                 unsigned long        const blu_mask,
-                 xel *                const xelrow) {
+convertRowTrueColor(pixelReader *  const pixelReaderP,
+                    int                  const cols,
+                    pixval               const maxval,
+                    const xel *          const colors,
+                    unsigned long        const red_mask,
+                    unsigned long        const grn_mask,
+                    unsigned long        const blu_mask,
+                    xel *                const xelrow) {
 
     unsigned int col;
     unsigned int red_shift, grn_shift, blu_shift;
@@ -1109,9 +1129,7 @@ convertTrueColor(FILE *               const ifp,
     for (col = 0; col < cols; ++col) {
         unsigned long pixel;
 
-        pixel = getpix(ifp, row_controlP, 
-                       bits_per_pixel, bits_per_item, 
-                       byte_order, bit_order);
+        pixel = getpix(pixelReaderP);
 
         /* The parsing of 'pixel' used to be done with hardcoded layout
            parameters.  See comments at end of this file.
@@ -1128,12 +1146,8 @@ convertTrueColor(FILE *               const ifp,
 
 
 static void
-convertRow(FILE*            const ifp, 
-           FILE*            const outfile,
-           int              const bits_per_pixel, 
-           int              const bits_per_item,
-           enum  byteorder  const byte_order, 
-           enum  byteorder  const bit_order,
+convertRow(pixelReader *    const pixelReaderP,
+           FILE *           const ofP,
            int              const padright, 
            int              const cols, 
            xelval           const maxval,
@@ -1143,14 +1157,17 @@ convertRow(FILE*            const ifp,
            unsigned long    const blue_mask, 
            const xel*       const colors, 
            enum visualclass const visualclass) {
+/*----------------------------------------------------------------------------
+   Read a row from the XWD pixel input stream 'pixelReaderP' and write
+   it to the PNM output stream 'ofP'.
 
+   The row is 'cols' pixels.
+
+   After reading the 'cols' pixels, we read and discard an additional
+   'padright' pixels from the input stream, so as to read the entire
+   input line.
+-----------------------------------------------------------------------------*/
     xel* xelrow;
-    struct row_control row_control;
-    /* Initialize the state of the getpix() row reader */
-    row_control.bits_left = 0;
-    row_control.carryover_bits = 0;
-    row_control.bits_carried_over = 0;
-    
     xelrow = pnm_allocrow(cols);
 
     switch (visualclass) {
@@ -1158,24 +1175,18 @@ convertRow(FILE*            const ifp,
     case GrayScale:
     case StaticColor:
     case PseudoColor:
-        convertSimpleIndex(ifp, cols, &row_control, colors, 
-                           bits_per_pixel, bits_per_item,
-                           byte_order, bit_order, xelrow);
+        convertRowSimpleIndex(pixelReaderP, cols, colors, xelrow);
         break;
     case DirectColor: 
-        convertDirect(ifp, cols, &row_control, colors,
-                      bits_per_pixel, bits_per_item,
-                      byte_order, bit_order, 
-                      red_mask, green_mask, blue_mask,
-                      xelrow);
+        convertRowDirect(pixelReaderP, cols, colors,
+                         red_mask, green_mask, blue_mask,
+                         xelrow);
         
         break;
     case TrueColor: 
-        convertTrueColor(ifp, cols, maxval, &row_control, colors,
-                         bits_per_pixel, bits_per_item,
-                         byte_order, bit_order, 
-                         red_mask, green_mask, blue_mask,
-                         xelrow);
+        convertRowTrueColor(pixelReaderP, cols, maxval, colors,
+                            red_mask, green_mask, blue_mask,
+                            xelrow);
         break;
             
     default:
@@ -1184,10 +1195,9 @@ convertRow(FILE*            const ifp,
     {
         unsigned int col;
         for (col = 0; col < padright; ++col)
-            getpix(ifp, &row_control, bits_per_pixel, bits_per_item,
-                   byte_order, bit_order);
+            getpix(pixelReaderP);
     }
-    pnm_writepnmrow(outfile, xelrow, cols, maxval, format, 0);
+    pnm_writepnmrow(ofP, xelrow, cols, maxval, format, 0);
     pnm_freerow(xelrow);
 }
 
@@ -1217,9 +1227,12 @@ reportOutputType(int const format) {
 
 
 int
-main( int argc, char *argv[] ) {
-    FILE* ifp;
-    int rows, cols, format, padright, row;
+main(int argc, char *argv[]) {
+
+    struct cmdlineInfo cmdline;
+    FILE * ifP;
+    int rows, cols, format, padright;
+    unsigned int row;
     int bits_per_pixel;
     int bits_per_item;
     unsigned long red_mask, green_mask, blue_mask;
@@ -1227,20 +1240,21 @@ main( int argc, char *argv[] ) {
     enum visualclass visualclass;
     enum byteorder byte_order, bit_order;
     xel *colors;  /* the color map */
+    pixelReader pixelReader;
 
-    pnm_init( &argc, argv );
+    pnm_init(&argc, argv);
 
     parseCommandLine(argc, argv, &cmdline);
 
     debug = cmdline.debug;
     verbose = cmdline.verbose;
 
-    if ( cmdline.input_filename != NULL ) 
-        ifp = pm_openr( cmdline.input_filename );
+    if (cmdline.input_filename != NULL) 
+        ifP = pm_openr(cmdline.input_filename);
     else
-        ifp = stdin;
+        ifP = stdin;
 
-    getinit(ifp, &cols, &rows, &padright, &maxval, &visualclass, &format, 
+    getinit(ifP, &cols, &rows, &padright, &maxval, &visualclass, &format, 
             &colors, &bits_per_pixel, &bits_per_item, 
             &red_mask, &green_mask, &blue_mask, &byte_order, &bit_order,
             cmdline.headerdump);
@@ -1251,21 +1265,24 @@ main( int argc, char *argv[] ) {
                    red_mask, green_mask, blue_mask, 
                    byte_order, bit_order);
 
-    pnm_writepnminit( stdout, cols, rows, maxval, format, 0 );
+    pixelReaderInit(&pixelReader, ifP, bits_per_pixel, bits_per_item,
+                    byte_order, bit_order);
+
+    pnm_writepnminit(stdout, cols, rows, maxval, format, 0);
 
     reportOutputType(format);
 
-    for ( row = 0; row < rows; ++row ) {
-        convertRow(ifp, stdout, bits_per_pixel, bits_per_item,
-                   byte_order, bit_order, padright, cols, maxval, format,
+    for (row = 0; row < rows; ++row) {
+        convertRow(&pixelReader, stdout,
+                   padright, cols, maxval, format,
                    red_mask, green_mask, blue_mask, colors, visualclass);
     }
     
-    pm_close( ifp );
-    pm_close( stdout );
+    pm_close(ifP);
+    pm_close(stdout);
     
-    exit( 0 );
-    }
+    return 0;
+}
 
 
 /*
