@@ -26,27 +26,24 @@
 #define MAXCOLORS 256
 
 enum colortype {TRUECOLOR, PALETTE};
-/*
- * Utilities
- */
 
-static struct cmdline_info {
+struct cmdlineInfo {
     /* All the information the user supplied in the command line,
        in a form easy for the program to use.
     */
-    char *input_filename;
-    int class;  /* C_WIN or C_OS2 */
+    const char * inputFilename;
+    int          class;  /* C_WIN or C_OS2 */
     unsigned int bppSpec;
     unsigned int bpp;
-} cmdline;
+};
 
 
 static void
-parse_command_line(int argc, char ** argv,
-                   struct cmdline_info *cmdline_p) {
+parseCommandLine(int argc, char ** argv,
+                 struct cmdlineInfo * const cmdlineP) {
 /*----------------------------------------------------------------------------
    Note that many of the strings that this function returns in the
-   *cmdline_p structure are actually in the supplied argv array.  And
+   *cmdlineP structure are actually in the supplied argv array.  And
    sometimes, one of these strings is actually just a suffix of an entry
    in argv!
 -----------------------------------------------------------------------------*/
@@ -62,8 +59,8 @@ parse_command_line(int argc, char ** argv,
     option_def_index = 0;   /* incremented by OPTENTRY */
     OPTENT3('w', "windows",   OPT_FLAG, NULL, &windowsSpec,            0);
     OPTENT3('o', "os2",       OPT_FLAG, NULL, &os2Spec,                0);
-    OPTENT3(0,   "bpp",       OPT_UINT, &cmdline_p->bpp, 
-            &cmdline_p->bppSpec,      0);
+    OPTENT3(0,   "bpp",       OPT_UINT, &cmdlineP->bpp, 
+            &cmdlineP->bppSpec,      0);
 
     opt.opt_table = option_def;
     opt.short_allowed = FALSE;  /* We have no short (old-fashioned) options */
@@ -74,25 +71,25 @@ parse_command_line(int argc, char ** argv,
     if (windowsSpec && os2Spec) 
         pm_error("Can't specify both -windows and -os2 options.");
     else if (windowsSpec) 
-        cmdline_p->class = C_WIN;
+        cmdlineP->class = C_WIN;
     else if (os2Spec)
-        cmdline_p->class = C_OS2;
+        cmdlineP->class = C_OS2;
     else 
-        cmdline_p->class = C_WIN;
+        cmdlineP->class = C_WIN;
 
 
-    if (cmdline_p->bppSpec) {
-        if (cmdline_p->bpp != 1 && cmdline_p->bpp != 4 && 
-            cmdline_p->bpp != 8 && cmdline_p->bpp != 24)
+    if (cmdlineP->bppSpec) {
+        if (cmdlineP->bpp != 1 && cmdlineP->bpp != 4 && 
+            cmdlineP->bpp != 8 && cmdlineP->bpp != 24)
         pm_error("Invalid -bpp value specified: %u.  The only values valid\n"
                  "in the BMP format are 1, 4, 8, and 24 bits per pixel",
-                 cmdline_p->bpp);
+                 cmdlineP->bpp);
     }
 
     if (argc - 1 == 0)
-        cmdline_p->input_filename = strdup("-");  /* he wants stdin */
+        cmdlineP->inputFilename = strdup("-");  /* he wants stdin */
     else if (argc - 1 == 1)
-        cmdline_p->input_filename = strdup(argv[1]);
+        cmdlineP->inputFilename = strdup(argv[1]);
     else 
         pm_error("Too many arguments.  The only argument accepted\n"
                  "is the input file specification");
@@ -276,11 +273,11 @@ BMPwritecolormap(FILE *        const fp,
 
 
 static int
-BMPwriterow_palette(FILE *          const fp, 
-                    const pixel *   const row, 
-                    unsigned long   const cx, 
-                    unsigned short  const bpp, 
-                    colorhash_table const cht) {
+BMPwriterowPalette(FILE *          const fp, 
+                   const pixel *   const row, 
+                   unsigned long   const cx, 
+                   unsigned short  const bpp, 
+                   colorhash_table const cht) {
 /*----------------------------------------------------------------------------
   Return the number of bytes written, or -1 on error.
 -----------------------------------------------------------------------------*/
@@ -332,10 +329,10 @@ BMPwriterow_palette(FILE *          const fp,
 
 
 static int
-BMPwriterow_truecolor(FILE *        const fp, 
-                      const pixel * const row, 
-                      unsigned long const cols,
-                      pixval        const maxval) {
+BMPwriterowTruecolor(FILE *        const fp, 
+                     const pixel * const row, 
+                     unsigned long const cols,
+                     pixval        const maxval) {
 /*----------------------------------------------------------------------------
   Write a row of a truecolor BMP image to the file 'fp'.  The row is 
   'row', which is 'cols' columns long.
@@ -348,7 +345,7 @@ BMPwriterow_truecolor(FILE *        const fp,
        general case (which is only hypothetical -- this program doesn't
        write any truecolor images except 24 bit and apparently no one
        else does either), you would move this function into 
-       BMPwriterow_palette, which writes arbitrary bit strings.  But
+       BMPwriterowPalette, which writes arbitrary bit strings.  But
        that would be a lot slower and less robust.
     */
 
@@ -402,10 +399,10 @@ BMPwritebits(FILE *          const fp,
     for (y = cy - 1; y >= 0; --y) {
         int rc;
         if (colortype == PALETTE)
-            rc = BMPwriterow_palette(fp, pixels[y], cx, 
-                                     cBitCount, cht);
+            rc = BMPwriterowPalette(fp, pixels[y], cx, 
+                                    cBitCount, cht);
         else 
-            rc = BMPwriterow_truecolor(fp, pixels[y], cx, maxval);
+            rc = BMPwriterowTruecolor(fp, pixels[y], cx, maxval);
 
         if (rc == -1)
             pm_error("couldn't write row %ld", y);
@@ -466,31 +463,31 @@ BMPEncode(FILE *          const fp,
 
 
 static void
-analyze_colors(const pixel **    const pixels, 
-               int               const cols, 
-               int               const rows, 
-               pixval            const maxval, 
-               int *             const colors_p, 
-               int *             const minimum_bpp_p,
-               colorhash_table * const cht_p, 
-               unsigned char           Red[], 
-               unsigned char           Green[], 
-               unsigned char           Blue[]) {
+analyzeColors(const pixel **    const pixels, 
+              int               const cols, 
+              int               const rows, 
+              pixval            const maxval, 
+              int *             const colorsP, 
+              int *             const minimumBppP,
+              colorhash_table * const chtP, 
+              unsigned char           Red[], 
+              unsigned char           Green[], 
+              unsigned char           Blue[]) {
 /*----------------------------------------------------------------------------
   Look at the colors in the image 'pixels' and compute values to use in
   representing those colors in a BMP image.  
 
-  First of all, count the distinct colors.  Return as *minimum_bpp_p
+  First of all, count the distinct colors.  Return as *minimumBppP
   the minimum number of bits per pixel it will take to represent all
   the colors in BMP format.
 
   If there are few enough colors to represent with a palette, also
-  return the number of colors as *colors_p and a suitable palette
+  return the number of colors as *colorsP and a suitable palette
   (colormap) and a hash table in which to look up indexes into that
-  palette as Red[], Green[], Blue[], and *cht_p.  Use only the first
-  *colors_p entries of the Red[], etc. array.
+  palette as Red[], Green[], Blue[], and *chtP.  Use only the first
+  *colorsP entries of the Red[], etc. array.
 
-  If there are too many colors for a palette, return *cht_p == NULL.
+  If there are too many colors for a palette, return *chtP == NULL.
 
   Issue informational messages.
 -----------------------------------------------------------------------------*/
@@ -501,15 +498,15 @@ analyze_colors(const pixel **    const pixels,
 
     pm_message("analyzing colors...");
     chv = ppm_computecolorhist((pixel**)pixels, cols, rows, MAXCOLORS, 
-                               colors_p);
+                               colorsP);
     if (chv == NULL) {
         pm_message("More than %d colors found", MAXCOLORS);
-        *minimum_bpp_p = 24;
-        *cht_p = NULL;
+        *minimumBppP = 24;
+        *chtP = NULL;
     } else {
-        unsigned int const minbits = pm_maxvaltobits(*colors_p-1);
+        unsigned int const minbits = pm_maxvaltobits(*colorsP-1);
 
-        pm_message("%d colors found", *colors_p);
+        pm_message("%d colors found", *colorsP);
 
         /* Only 1, 4, 8, and 24 are defined in the BMP spec we
            implement and other bpp's have in fact been seen to confuse
@@ -518,25 +515,25 @@ analyze_colors(const pixel **    const pixels,
            (see Bmptopnm.c, though).  
         */
         if (minbits == 1)
-            *minimum_bpp_p = 1;
+            *minimumBppP = 1;
         else if (minbits <= 4)
-            *minimum_bpp_p = 4;
+            *minimumBppP = 4;
         else if (minbits <= 8)
-            *minimum_bpp_p = 8;
+            *minimumBppP = 8;
         else
-            *minimum_bpp_p = 24;
+            *minimumBppP = 24;
 
         /*
          * Now scale the maxval to 255 as required by BMP format.
          */
-        for (i = 0; i < *colors_p; ++i) {
+        for (i = 0; i < *colorsP; ++i) {
             Red[i] = (pixval) PPM_GETR(chv[i].color) * 255 / maxval;
             Green[i] = (pixval) PPM_GETG(chv[i].color) * 255 / maxval;
             Blue[i] = (pixval) PPM_GETB(chv[i].color) * 255 / maxval;
         }
     
         /* And make a hash table for fast lookup. */
-        *cht_p = ppm_colorhisttocolorhash(chv, *colors_p);
+        *chtP = ppm_colorhisttocolorhash(chv, *colorsP);
         ppm_freecolorhist(chv);
     }
 }
@@ -544,19 +541,19 @@ analyze_colors(const pixel **    const pixels,
 
 
 static void
-choose_colortype_bpp(struct cmdline_info const cmdline,
-                     int                 const colors, 
-                     int                 const minimum_bpp,
-                     enum colortype *    const colortype_p, 
-                     int *               const bits_per_pixel_p) {
+chooseColortypeBpp(struct cmdlineInfo const cmdline,
+                   int                 const colors, 
+                   int                 const minimumBpp,
+                   enum colortype *    const colortypeP, 
+                   int *               const bitsPerPixelP) {
 
     if (!cmdline.bppSpec) {
         /* User has no preference as to bits per pixel.  Choose the
            smallest number possible for this image.
         */
-        *bits_per_pixel_p = minimum_bpp;
+        *bitsPerPixelP = minimumBpp;
     } else {
-        if (cmdline.bpp < minimum_bpp)
+        if (cmdline.bpp < minimumBpp)
             pm_error("There are too many colors in the image to "
                      "represent in the\n"
                      "number of bits per pixel you requested: %d.\n"
@@ -564,18 +561,18 @@ choose_colortype_bpp(struct cmdline_info const cmdline,
                      "colors in the image.",
                      cmdline.bpp);
         else
-            *bits_per_pixel_p = cmdline.bpp;
+            *bitsPerPixelP = cmdline.bpp;
     }
 
-    assert(*bits_per_pixel_p == 1 || 
-           *bits_per_pixel_p == 4 || 
-           *bits_per_pixel_p == 8 || 
-           *bits_per_pixel_p == 24);
+    assert(*bitsPerPixelP == 1 || 
+           *bitsPerPixelP == 4 || 
+           *bitsPerPixelP == 8 || 
+           *bitsPerPixelP == 24);
 
-    if (*bits_per_pixel_p > 8) 
-        *colortype_p = TRUECOLOR;
+    if (*bitsPerPixelP > 8) 
+        *colortypeP = TRUECOLOR;
     else {
-        *colortype_p = PALETTE;
+        *colortypeP = PALETTE;
     }
 }
 
@@ -583,14 +580,15 @@ choose_colortype_bpp(struct cmdline_info const cmdline,
 
 int
 main(int argc, char **argv) {
-    FILE *ifp;
 
+    struct cmdlineInfo cmdline;
+    FILE *ifp;
     int rows;
     int cols;
     int colors;
     pixval maxval;
-    int minimum_bpp;
-    int bits_per_pixel;
+    int minimumBpp;
+    int bitsPerPixel;
     enum colortype colortype;
 
     pixel** pixels;
@@ -602,22 +600,22 @@ main(int argc, char **argv) {
 
     ppm_init(&argc, argv);
 
-    parse_command_line(argc, argv, &cmdline);
+    parseCommandLine(argc, argv, &cmdline);
 
-    ifp = pm_openr(cmdline.input_filename);
+    ifp = pm_openr(cmdline.inputFilename);
 
     pixels = ppm_readppm(ifp, &cols, &rows, &maxval);
 
     pm_close(ifp);
 
 
-    analyze_colors((const pixel**)pixels, cols, rows, maxval, 
-                   &colors, &minimum_bpp, &cht, Red, Green, Blue);
+    analyzeColors((const pixel**)pixels, cols, rows, maxval, 
+                   &colors, &minimumBpp, &cht, Red, Green, Blue);
 
-    choose_colortype_bpp(cmdline, colors, minimum_bpp, &colortype, 
-                         &bits_per_pixel);
+    chooseColortypeBpp(cmdline, colors, minimumBpp, &colortype, 
+                       &bitsPerPixel);
 
-    BMPEncode(stdout, cmdline.class, colortype, bits_per_pixel,
+    BMPEncode(stdout, cmdline.class, colortype, bitsPerPixel,
               cols, rows, (const pixel**)pixels, maxval, colors, cht,
               Red, Green, Blue);
 
