@@ -326,14 +326,6 @@ BumpPixel()
                           if( cury >= Height ) {
                                 ++Pass;
                                 cury = 4;
-                                if (cury >= Height) {
-                                    ++Pass;
-                                    cury = 2;
-                                    if (cury >= Height) {
-                                        ++Pass;
-                                        cury = 1;
-                                    }
-                                }
                           }
                           break;
 
@@ -342,10 +334,6 @@ BumpPixel()
                           if( cury >= Height ) {
                                 ++Pass;
                                 cury = 2;
-                                if (cury >= Height) {
-                                    ++Pass;
-                                    cury = 1;
-                                }
                           }
                           break;
 
@@ -1008,7 +996,7 @@ writeGifHeader(FILE * const fp,
     Putword( Width, fp );
     Putword( Height, fp );
 
-    /* Indicate that there is a global colour map */
+    /* Indicate that there is a global color map */
     B = 0x80;       /* Yes, there is a color map */
 
     /* OR in the resolution */
@@ -1068,14 +1056,6 @@ GIFEncode(FILE * const fp,
     int const TopOfs = 0;
     int InitCodeSize;
     
-    if (GWidth > 65535)
-        pm_error("Image width %u too large for GIF format.  (Max 65535)",
-                 GWidth);  
-    
-    if (GHeight > 65535)
-        pm_error("Image height %u too large for GIF format.  (Max 65535)",
-                 GHeight);  
-
     writeGifHeader(fp, GWidth, GHeight, GInterlace, Background,
                    BitsPerPixel, cmapP, comment);
 
