@@ -39,99 +39,6 @@
  * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
  */
 
-/*
- *  $Header: /n/picasso/project/mpeg/mpeg_dist/mpeg_encode/RCS/iframe.c,v 1.23 1995/08/14 22:29:49 smoot Exp $
- *  $Log: iframe.c,v $
- *  Revision 1.23  1995/08/14 22:29:49  smoot
- *  changed inits in BlockComputeSNR so sgi compiler would be happy
- *
- *  Revision 1.22  1995/08/07 21:50:51  smoot
- *  spacing
- *  simplified some code
- *  added Laplace stuff
- *  minor error check bug in alloc
- *
- * Revision 1.21  1995/06/21  22:24:25  smoot
- * added CalcDistortion (TUNEing)
- * fixed timeing stuff for ANSI
- * fixed specifics bug
- *
- * Revision 1.20  1995/05/02  21:59:43  smoot
- * fixed BlockComputeSNR bugs
- *
- * Revision 1.19  1995/04/24  23:02:50  smoot
- * Fixed BlockComputeSNR for Linux and others
- *
- * Revision 1.18  1995/04/14  23:08:02  smoot
- * reorganized to ease rate control experimentation
- *
- * Revision 1.17  1995/02/24  23:49:38  smoot
- * added handling of Specifics file version 2
- *
- * Revision 1.16  1995/01/30  20:02:34  smoot
- * cleanup, killed a couple warnings
- *
- * Revision 1.15  1995/01/30  19:49:17  smoot
- * cosmetic
- *
- * Revision 1.14  1995/01/23  02:49:34  darryl
- * initialized variable
- *
- * Revision 1.13  1995/01/19  23:08:30  eyhung
- * Changed copyrights
- *
- * Revision 1.12  1995/01/16  08:01:34  eyhung
- * Added realQuiet
- *
- * Revision 1.11  1994/12/07  00:40:36  smoot
- * Added seperate P and B search ranges
- *
- * Revision 1.10  1994/11/14  22:30:30  smoot
- * Merged specifics and rate control
- *
- * Revision 1.9  1994/11/01  05:00:48  darryl
- * with rate control changes added
- *
- * Revision 2.2  1994/10/31  00:06:07  darryl
- * version before, hopefully, final changes
- *
- * Revision 2.1  1994/10/24  22:03:01  darryl
- * put in preliminary experiments code
- *
- * Revision 2.0  1994/10/24  02:38:04  darryl
- * will be adding the experiment stuff.
- *
- * Revision 1.1  1994/09/27  00:15:24  darryl
- * Initial revision
- *
- * Revision 1.8  1994/03/15  00:27:11  keving
- * nothing
- *
- * Revision 1.7  1993/12/22  19:19:01  keving
- * nothing
- *
- * Revision 1.6  1993/07/22  22:23:43  keving
- * nothing
- *
- * Revision 1.5  1993/06/30  20:06:09  keving
- * nothing
- *
- * Revision 1.4  1993/06/03  21:08:08  keving
- * nothing
- *
- * Revision 1.3  1993/03/04  22:24:06  keving
- * nothing
- *
- * Revision 1.2  1993/02/19  18:10:02  keving
- * nothing
- *
- * Revision 1.1  1993/02/18  22:56:39  keving
- * nothing
- *
- *
- */
-
-
 /*==============*
  * HEADER FILES *
  *==============*/
@@ -233,55 +140,56 @@ extern void PrintItoIBitRate _ANSI_ARGS_((int numBits, int frameNum));
 /*===============================*
  * INTERNAL PROCEDURE prototypes *
  *===============================*/
-void AllocDctBlocks _ANSI_ARGS_((void ));
-int SetFCodeHelper _ANSI_ARGS_((int sr));
-void CalcDistortion _ANSI_ARGS_((MpegFrame *current, int y, int x));
+void AllocDctBlocks(void );
+int SetFCodeHelper (int sr);
+void CalcDistortion (MpegFrame *current, int y, int x);
 
 int
-  SetFCodeHelper(SR)
-int SR;
-{
+SetFCodeHelper(int const SR) {
+
     int     range,fCode;
 
     if ( pixelFullSearch ) {
-    range = SR;
+        range = SR;
     } else {
-    range = SR*2;
+        range = SR*2;
     }
 
     if ( range < 256 ) {
-    if ( range < 64 ) {
-        if ( range < 32 ) {
-        fCode = 1;
+        if ( range < 64 ) {
+            if ( range < 32 ) {
+                fCode = 1;
+            } else {
+                fCode = 2;
+            }
         } else {
-        fCode = 2;
+            if ( range < 128 ) {
+                fCode = 3;
+            } else {
+                fCode = 4;
+            }
         }
     } else {
-        if ( range < 128 ) {
-        fCode = 3;
+        if ( range < 1024 ) {
+            if ( range < 512 ) {
+                fCode = 5;
+            } else {
+                fCode = 6;
+            }
         } else {
-        fCode = 4;
+            if ( range < 2048 ) {
+                fCode = 7;
+            } else {
+                fprintf(stderr, "ERROR:  INVALID SEARCH RANGE!!!\n");
+                exit(1);
+            }
         }
     }
-    } else {
-    if ( range < 1024 ) {
-        if ( range < 512 ) {
-        fCode = 5;
-        } else {
-        fCode = 6;
-        }
-    } else {
-        if ( range < 2048 ) {
-        fCode = 7;
-        } else {
-        fprintf(stderr, "ERROR:  INVALID SEARCH RANGE!!!\n");
-        exit(1);
-        }
-    }
-      }
     return fCode;
 }
 
+
+
 /*===========================================================================*
  *
  * SetFCode
@@ -297,13 +205,14 @@ int SR;
  *
  *===========================================================================*/
 void
-SetFCode()
-{
-  fCodeI = SetFCodeHelper(1); /* GenIFrame ignores value */
-  fCodeP = SetFCodeHelper(searchRangeP);
-  fCodeB = SetFCodeHelper(searchRangeB);
+SetFCode(void) {
+    fCodeI = SetFCodeHelper(1); /* GenIFrame ignores value */
+    fCodeP = SetFCodeHelper(searchRangeP);
+    fCodeB = SetFCodeHelper(searchRangeB);
 }
 
+
+
 /*===========================================================================*
  *
  * SetSlicesPerFrame
@@ -316,13 +225,13 @@ SetFCode()
  *
  *===========================================================================*/
 void
-SetSlicesPerFrame(number)
-    int number;
-{
+SetSlicesPerFrame(int const number) {
+
     slicesPerFrame = number;
 }
 
 
+
 /*===========================================================================*
  *
  * SetBlocksPerSlice
@@ -335,20 +244,21 @@ SetSlicesPerFrame(number)
  *
  *===========================================================================*/
 void
-SetBlocksPerSlice()
-{
-    int     totalBlocks;
+SetBlocksPerSlice(void) {
 
+    int     totalBlocks;
+    
     totalBlocks = (Fsize_y>>4)*(Fsize_x>>4);
 
     if ( slicesPerFrame > totalBlocks ) {
-    blocksPerSlice = 1;
+        blocksPerSlice = 1;
     } else {
-    blocksPerSlice = totalBlocks/slicesPerFrame;
+        blocksPerSlice = totalBlocks/slicesPerFrame;
     }
 }
 
 
+
 /*===========================================================================*
  *
  * SetIQScale
@@ -361,12 +271,12 @@ SetBlocksPerSlice()
  *
  *===========================================================================*/
 void
-SetIQScale(qI)
-int qI;
-{
+SetIQScale(int const qI) {
     qscaleI = qI;
 }
 
+
+
 /*===========================================================================*
  *
  * GetIQScale
@@ -379,11 +289,12 @@ int qI;
  *
  *===========================================================================*/
 int
-GetIQScale()
-{
+GetIQScale(void) {
     return qscaleI;
 }
 
+
+
 /*===========================================================================*
  *
  * GenIFrame
@@ -645,8 +556,7 @@ GenIFrame(BitBucket * const bb,
  *
  *===========================================================================*/
 void
-ResetIFrameStats()
-{
+ResetIFrameStats(void) {
     numBlocks = 0;
     numBits = 0;
     numFrames = 0;
@@ -735,11 +645,10 @@ EstimateSecondsPerIFrame()
  *
  *===========================================================================*/
 void
-EncodeYDC(dc_term, pred_term, bb)
-    int32 dc_term;
-    int32 *pred_term;
-    BitBucket *bb;
-{
+EncodeYDC(int32       const dc_term,
+          int32 *     const pred_term,
+          BitBucket * const bb) {
+
     /* see Table B.5a -- MPEG-I doc */
     static int codes[9] = {
     0x4, 0x0, 0x1, 0x5, 0x6, 0xe, 0x1e, 0x3e, 0x7e
@@ -778,6 +687,7 @@ EncodeYDC(dc_term, pred_term, bb)
 }
 
 
+
 /*===========================================================================*
  *
  * EncodeCDC
@@ -790,17 +700,16 @@ EncodeYDC(dc_term, pred_term, bb)
  *
  *===========================================================================*/
 void
-EncodeCDC(dc_term, pred_term, bb)
-    int32 dc_term;
-    int32 *pred_term;
-    BitBucket *bb;
-{
+EncodeCDC(int32       const dc_term,
+          int32     * const pred_term,
+          BitBucket * const bb) {
+
     /* see Table B.5b -- MPEG-I doc */
     static int codes[9] = {
-    0x0, 0x1, 0x2, 0x6, 0xe, 0x1e, 0x3e, 0x7e, 0xfe
+        0x0, 0x1, 0x2, 0x6, 0xe, 0x1e, 0x3e, 0x7e, 0xfe
     };
     static int codeLengths[9] = {
-    2,   2,   2,   3,   4,   5,    6,    7,    8
+        2,   2,   2,   3,   4,   5,    6,    7,    8
     };
     int cdiff, cdiff_abs;
     int length;
@@ -808,155 +717,158 @@ EncodeCDC(dc_term, pred_term, bb)
     cdiff = (dc_term - (*pred_term));
     if (cdiff > 255) {
 #ifdef BLEAH
-fprintf(stdout, "TRUNCATED\n"); 
+        fprintf(stdout, "TRUNCATED\n"); 
 #endif
-    cdiff = 255;
+        cdiff = 255;
     } else if (cdiff < -255) {
 #ifdef BLEAH
-fprintf(stdout, "TRUNCATED\n"); 
+        fprintf(stdout, "TRUNCATED\n"); 
 #endif
-    cdiff = -255;
+        cdiff = -255;
     }
 
     cdiff_abs = ABS(cdiff);
     length = lengths[cdiff_abs];
     Bitio_Write(bb, codes[length], codeLengths[length]);
     if ( length != 0 ) {
-    if ( cdiff > 0 ) {
-        Bitio_Write(bb, cdiff_abs, length);
-    } else {
-        Bitio_Write(bb, ~cdiff_abs, length);
-    }
+        if ( cdiff > 0 ) {
+            Bitio_Write(bb, cdiff_abs, length);
+        } else {
+            Bitio_Write(bb, ~cdiff_abs, length);
+        }
     }
 
     (*pred_term) += cdiff;
 }
 
 
+
 void
-BlockComputeSNR(current, snr, psnr)
-     MpegFrame *current;
-     float snr[];
-     float psnr[];
-{
-  register int32    tempInt;
-  register int y, x;
-  int32 varDiff[3];
-  double    ratio[3];
-  double    total[3];
-  register uint8 **origY=current->orig_y, **origCr=current->orig_cr, 
-  **origCb=current->orig_cb;
-  register uint8 **newY=current->decoded_y, **newCr=current->decoded_cr, 
-  **newCb=current->decoded_cb;
-  static int32       **SignalY,  **NoiseY;
-  static int32       **SignalCb, **NoiseCb;
-  static int32       **SignalCr, **NoiseCr;
-  static short   ySize[3], xSize[3];
-  static boolean needs_init=TRUE;
+BlockComputeSNR(MpegFrame * const current,
+                float *     const snr,
+                float *     const psnr) {
+
+    int32    tempInt;
+    int y, x;
+    int32 varDiff[3];
+    double    ratio[3];
+    double    total[3];
+    uint8 **origY=current->orig_y, **origCr=current->orig_cr, 
+        **origCb=current->orig_cb;
+    uint8 **newY=current->decoded_y, **newCr=current->decoded_cr, 
+        **newCb=current->decoded_cb;
+    static int32       **SignalY,  **NoiseY;
+    static int32       **SignalCb, **NoiseCb;
+    static int32       **SignalCr, **NoiseCr;
+    static short   ySize[3], xSize[3];
+    static boolean needs_init=TRUE;
   
-  /* Init */
-  if (needs_init) {
-    int ysz = (Fsize_y>>3) * sizeof(int32 *);
-    int xsz = (Fsize_x>>3);
+    /* Init */
+    if (needs_init) {
+        int ysz = (Fsize_y>>3) * sizeof(int32 *);
+        int xsz = (Fsize_x>>3);
     
-    needs_init = FALSE;
-    for (y=0; y<3; y++) {
-      varDiff[y] = ratio[y] = total[y] = 0.0;
+        needs_init = FALSE;
+        for (y=0; y<3; y++) {
+            varDiff[y] = ratio[y] = total[y] = 0.0;
+        }
+        ySize[0]=Fsize_y;     xSize[0]=Fsize_x;
+        ySize[1]=Fsize_y>>1;  xSize[1]=Fsize_x>>1;
+        ySize[2]=Fsize_y>>1;  xSize[2]=Fsize_x>>1;
+        SignalY  = (int32 **) malloc(ysz);
+        NoiseY   = (int32 **) malloc(ysz);
+        SignalCb = (int32 **) malloc(ysz);
+        NoiseCb  = (int32 **) malloc(ysz);
+        SignalCr = (int32 **) malloc(ysz);
+        NoiseCr  = (int32 **) malloc(ysz);
+        if (SignalY == NULL || NoiseY == NULL || SignalCr == NULL || 
+            NoiseCb == NULL || SignalCb == NULL || NoiseCr == NULL) {
+            fprintf(stderr, "Out of memory in BlockComputeSNR\n");
+            exit(-1);
+        }
+        for (y = 0; y < ySize[0]>>3; y++) {
+            SignalY[y]  = (int32 *) calloc(xsz,4);
+            SignalCr[y]  = (int32 *) calloc(xsz,4);
+            SignalCb[y]  = (int32 *) calloc(xsz,4);
+            NoiseY[y]  = (int32 *) calloc(xsz,4);
+            NoiseCr[y]  = (int32 *) calloc(xsz,4);
+            NoiseCb[y]  = (int32 *) calloc(xsz,4);
+        }
+    } else {
+        for (y = 0; y < ySize[0]>>3; y++) {
+            memset((char *) &NoiseY[y][0], 0, (xSize[0]>>3) * 4);
+            memset((char *) &SignalY[y][0], 0, (xSize[0]>>3) * 4);
+            memset((char *) &NoiseCb[y][0], 0, (xSize[0]>>3) * 4);
+            memset((char *) &NoiseCr[y][0], 0, (xSize[0]>>3) * 4);
+            memset((char *) &SignalCb[y][0], 0, (xSize[0]>>3) * 4);
+            memset((char *) &SignalCr[y][0], 0, (xSize[0]>>3) * 4);
+        }
     }
-    ySize[0]=Fsize_y;     xSize[0]=Fsize_x;
-    ySize[1]=Fsize_y>>1;  xSize[1]=Fsize_x>>1;
-    ySize[2]=Fsize_y>>1;  xSize[2]=Fsize_x>>1;
-    SignalY  = (int32 **) malloc(ysz);
-    NoiseY   = (int32 **) malloc(ysz);
-    SignalCb = (int32 **) malloc(ysz);
-    NoiseCb  = (int32 **) malloc(ysz);
-    SignalCr = (int32 **) malloc(ysz);
-    NoiseCr  = (int32 **) malloc(ysz);
-    if (SignalY == NULL || NoiseY == NULL || SignalCr == NULL || 
-    NoiseCb == NULL || SignalCb == NULL || NoiseCr == NULL) {
-      fprintf(stderr, "Out of memory in BlockComputeSNR\n");
-      exit(-1);
-    }
-    for (y = 0; y < ySize[0]>>3; y++) {
-      SignalY[y]  = (int32 *) calloc(xsz,4);
-      SignalCr[y]  = (int32 *) calloc(xsz,4);
-      SignalCb[y]  = (int32 *) calloc(xsz,4);
-      NoiseY[y]  = (int32 *) calloc(xsz,4);
-      NoiseCr[y]  = (int32 *) calloc(xsz,4);
-      NoiseCb[y]  = (int32 *) calloc(xsz,4);
-    }
-  } else {
-    for (y = 0; y < ySize[0]>>3; y++) {
-      memset((char *) &NoiseY[y][0], 0, (xSize[0]>>3) * 4);
-      memset((char *) &SignalY[y][0], 0, (xSize[0]>>3) * 4);
-      memset((char *) &NoiseCb[y][0], 0, (xSize[0]>>3) * 4);
-      memset((char *) &NoiseCr[y][0], 0, (xSize[0]>>3) * 4);
-      memset((char *) &SignalCb[y][0], 0, (xSize[0]>>3) * 4);
-      memset((char *) &SignalCr[y][0], 0, (xSize[0]>>3) * 4);
-    }
-  }
   
-  /* find all the signal and noise */
-  for (y = 0; y < ySize[0]; y++) {
-    for (x = 0; x < xSize[0]; x++) {
-      tempInt = (origY[y][x] - newY[y][x]);
-      NoiseY[y>>4][x>>4] += tempInt*tempInt;
-      total[0] += (double)abs(tempInt);
-      tempInt = origY[y][x];
-      SignalY[y>>4][x>>4] += tempInt*tempInt;
-    }}
-  for (y = 0; y < ySize[1]; y++) {
-    for (x = 0; x < xSize[1]; x ++) {
-      tempInt = (origCb[y][x] - newCb[y][x]);
-      NoiseCb[y>>3][x>>3] += tempInt*tempInt;
-      total[1] += (double)abs(tempInt);
-      tempInt = origCb[y][x];
-      SignalCb[y>>3][x>>3] += tempInt*tempInt;
-      tempInt = (origCr[y][x]-newCr[y][x]);
-      NoiseCr[y>>3][x>>3] += tempInt*tempInt;
-      total[2] += (double)abs(tempInt);
-      tempInt = origCr[y][x];
-      SignalCr[y>>3][x>>3] += tempInt*tempInt;
-    }}
+    /* find all the signal and noise */
+    for (y = 0; y < ySize[0]; y++) {
+        for (x = 0; x < xSize[0]; x++) {
+            tempInt = (origY[y][x] - newY[y][x]);
+            NoiseY[y>>4][x>>4] += tempInt*tempInt;
+            total[0] += (double)abs(tempInt);
+            tempInt = origY[y][x];
+            SignalY[y>>4][x>>4] += tempInt*tempInt;
+        }}
+    for (y = 0; y < ySize[1]; y++) {
+        for (x = 0; x < xSize[1]; x ++) {
+            tempInt = (origCb[y][x] - newCb[y][x]);
+            NoiseCb[y>>3][x>>3] += tempInt*tempInt;
+            total[1] += (double)abs(tempInt);
+            tempInt = origCb[y][x];
+            SignalCb[y>>3][x>>3] += tempInt*tempInt;
+            tempInt = (origCr[y][x]-newCr[y][x]);
+            NoiseCr[y>>3][x>>3] += tempInt*tempInt;
+            total[2] += (double)abs(tempInt);
+            tempInt = origCr[y][x];
+            SignalCr[y>>3][x>>3] += tempInt*tempInt;
+        }}
   
-  /* Now sum up that noise */
-  for(y=0; y<Fsize_y>>4; y++){
-    for(x=0; x<Fsize_x>>4; x++){
-      varDiff[0] += NoiseY[y][x];
-      varDiff[1] += NoiseCb[y][x];
-      varDiff[2] += NoiseCr[y][x];
-      if (printMSE) printf("%4d ",(int)(NoiseY[y][x]/256.0));
+    /* Now sum up that noise */
+    for(y=0; y<Fsize_y>>4; y++){
+        for(x=0; x<Fsize_x>>4; x++){
+            varDiff[0] += NoiseY[y][x];
+            varDiff[1] += NoiseCb[y][x];
+            varDiff[2] += NoiseCr[y][x];
+            if (printMSE) printf("%4d ",(int)(NoiseY[y][x]/256.0));
+        }
+        if (printMSE) puts("");
     }
-    if (printMSE) puts("");
-  }
   
-  /* Now look at those ratios! */
-  for(y=0; y<Fsize_y>>4; y++){
-    for(x=0; x<Fsize_x>>4; x++){
-      ratio[0] += (double)SignalY[y][x]/(double)varDiff[0];
-      ratio[1] += (double)SignalCb[y][x]/(double)varDiff[1];
-      ratio[2] += (double)SignalCr[y][x]/(double)varDiff[2];
-    }}
+    /* Now look at those ratios! */
+    for(y=0; y<Fsize_y>>4; y++){
+        for(x=0; x<Fsize_x>>4; x++){
+            ratio[0] += (double)SignalY[y][x]/(double)varDiff[0];
+            ratio[1] += (double)SignalCb[y][x]/(double)varDiff[1];
+            ratio[2] += (double)SignalCr[y][x]/(double)varDiff[2];
+        }}
   
-  for (x=0; x<3; x++) {
-    snr[x] = 10.0*log10(ratio[x]);
-    psnr[x] = 20.0*log10(255.0/sqrt((double)varDiff[x]/(double)(ySize[x]*xSize[x])));
+    for (x=0; x<3; x++) {
+        snr[x] = 10.0 * log10(ratio[x]);
+        psnr[x] = 20.0 * log10(255.0/sqrt((double)varDiff[x]/
+                                          (double)(ySize[x]*xSize[x])));
 
-    if (! realQuiet) {
-      fprintf(stdout, "Mean error[%1d]:  %f\n", x, total[x]/(double)(xSize[x]*ySize[x]));
-    }
+        if (! realQuiet) {
+            fprintf(stdout, "Mean error[%1d]:  %f\n",
+                    x, total[x] / (double)(xSize[x] * ySize[x]));
+        }
 
-  }
+    }
 }
 
+
+
 void
-WriteDecodedFrame(frame)
-    MpegFrame *frame;
-{
-    FILE    *fpointer;
-    char    fileName[256];
-    int width, height;
-    register int y;
+WriteDecodedFrame(MpegFrame * const frame) {
+
+    FILE * fpointer;
+    char   fileName[256];
+    int    width, height;
+    int    y;
 
     /* need to save decoded frame to disk because it might be accessed
        by another process */
@@ -967,8 +879,8 @@ WriteDecodedFrame(frame)
     sprintf(fileName, "%s.decoded.%d", outputFileName, frame->id);
 
     if (!realQuiet) {
-    fprintf(stdout, "Outputting to %s\n", fileName);
-    fflush(stdout);
+        fprintf(stdout, "Outputting to %s\n", fileName);
+        fflush(stdout);
     }
 
     fpointer = fopen(fileName, "wb");
@@ -989,29 +901,30 @@ WriteDecodedFrame(frame)
 }
 
 
-void
-PrintItoIBitRate(numBits, frameNum)
-    int     numBits;
-    int     frameNum;
-{
-    if ( showBitRatePerFrame ) {
-    /* ASSUMES 30 FRAMES PER SECOND */
 
-    if (! realQuiet) {
-    fprintf(stdout, "I-to-I (frames %5d to %5d) bitrate:  %8d\n",
-        lastIFrame, frameNum-1,
-        ((numBits-lastNumBits)*30)/
-        (frameNum-lastIFrame));
+void
+PrintItoIBitRate(int const numBits,
+                 int const frameNum) {
+
+    if ( showBitRatePerFrame ) {
+        /* ASSUMES 30 FRAMES PER SECOND */
+
+        if (! realQuiet) {
+            fprintf(stdout, "I-to-I (frames %5d to %5d) bitrate:  %8d\n",
+                    lastIFrame, frameNum-1,
+                    ((numBits-lastNumBits)*30)/
+                    (frameNum-lastIFrame));
         }
 
-    fprintf(bitRateFile, "I-to-I (frames %5d to %5d) bitrate:  %8d\n",
-        lastIFrame, frameNum-1,
-        ((numBits-lastNumBits)*30)/
-        (frameNum-lastIFrame));
+        fprintf(bitRateFile, "I-to-I (frames %5d to %5d) bitrate:  %8d\n",
+                lastIFrame, frameNum-1,
+                ((numBits-lastNumBits)*30)/
+                (frameNum-lastIFrame));
     }
 }
 
 
+
 /*===========================================================================*
  *
  * AllocDctBlocks
@@ -1024,8 +937,7 @@ PrintItoIBitRate(numBits, frameNum)
  *
  *===========================================================================*/
 void
-AllocDctBlocks()
-{
+AllocDctBlocks(void) {
     int dctx, dcty;
     int i;
 
@@ -1035,15 +947,15 @@ AllocDctBlocks()
     dct = (Block **) malloc(sizeof(Block *) * dcty);
     ERRCHK(dct, "malloc");
     for (i = 0; i < dcty; i++) {
-    dct[i] = (Block *) malloc(sizeof(Block) * dctx);
-    ERRCHK(dct[i], "malloc");
+        dct[i] = (Block *) malloc(sizeof(Block) * dctx);
+        ERRCHK(dct[i], "malloc");
     }
 
     dct_data = (dct_data_type **) malloc(sizeof(dct_data_type *) * dcty);
     ERRCHK(dct_data, "malloc");
     for (i = 0; i < dcty; i++) {
-    dct_data[i] = (dct_data_type *) malloc(sizeof(dct_data_type) * dctx);
-    ERRCHK(dct[i], "malloc");
+        dct_data[i] = (dct_data_type *) malloc(sizeof(dct_data_type) * dctx);
+        ERRCHK(dct[i], "malloc");
     }
 
     dctr = (Block **) malloc(sizeof(Block *) * (dcty >> 1));
@@ -1051,14 +963,15 @@ AllocDctBlocks()
     ERRCHK(dctr, "malloc");
     ERRCHK(dctb, "malloc");
     for (i = 0; i < (dcty >> 1); i++) {
-    dctr[i] = (Block *) malloc(sizeof(Block) * (dctx >> 1));
-    dctb[i] = (Block *) malloc(sizeof(Block) * (dctx >> 1));
-    ERRCHK(dctr[i], "malloc");
-    ERRCHK(dctb[i], "malloc");
+        dctr[i] = (Block *) malloc(sizeof(Block) * (dctx >> 1));
+        dctb[i] = (Block *) malloc(sizeof(Block) * (dctx >> 1));
+        ERRCHK(dctr[i], "malloc");
+        ERRCHK(dctb[i], "malloc");
     }
 }
 
 
+
 /*======================================================================*
  *
  * time_elapsed
@@ -1068,80 +981,79 @@ AllocDctBlocks()
  *  RETURNS number of seconds process time used
  *
  *======================================================================*/
-int32 time_elapsed()
-{
+int32 time_elapsed(void) {
 #ifdef CLOCKS_PER_SEC
- /* ANSI C */
-  TIME_RATE = CLOCKS_PER_SEC;
-  return (int32) clock();
+    /* ANSI C */
+    TIME_RATE = CLOCKS_PER_SEC;
+    return (int32) clock();
 #else
-  struct tms   timeBuffer;
-  TIME_RATE = 60;
-  times(&timeBuffer);
-  return timeBuffer.tms_utime + timeBuffer.tms_stime;
+    struct tms   timeBuffer;
+    TIME_RATE = 60;
+    times(&timeBuffer);
+    return timeBuffer.tms_utime + timeBuffer.tms_stime;
 #endif
 }
 
 
+
 void
-CalcDistortion(current, y, x)
-MpegFrame *current;
-int y,x;
-{
+CalcDistortion(MpegFrame * const current,
+               int         const y,
+               int         const x) {
 
-  int qscale, distort=0;
-  Block decblk;
-  FlatBlock fblk;
-  int datarate = 0;
+    int qscale, distort=0;
+    Block decblk;
+    FlatBlock fblk;
+    int datarate = 0;
   
-  for (qscale = 1; qscale < 32; qscale ++) {
-    distort = 0;
-    datarate = 0;
-    Mpost_QuantZigBlock(dct[y][x], fblk, qscale, TRUE);
-    Mpost_UnQuantZigBlock(fblk, decblk, qscale, TRUE);
-    if (collect_distortion_detailed) datarate += CalcRLEHuffLength(fblk);
-    mpeg_jrevdct((int16 *)decblk);
-    distort += mse(current->y_blocks[y][x], decblk);
+    for (qscale = 1; qscale < 32; qscale ++) {
+        distort = 0;
+        datarate = 0;
+        Mpost_QuantZigBlock(dct[y][x], fblk, qscale, TRUE);
+        Mpost_UnQuantZigBlock(fblk, decblk, qscale, TRUE);
+        if (collect_distortion_detailed) datarate += CalcRLEHuffLength(fblk);
+        mpeg_jrevdct((int16 *)decblk);
+        distort += mse(current->y_blocks[y][x], decblk);
 
-    Mpost_QuantZigBlock(dct[y][x+1], fblk, qscale, TRUE);
-    Mpost_UnQuantZigBlock(fblk, decblk, qscale, TRUE);
-    if (collect_distortion_detailed) datarate += CalcRLEHuffLength(fblk);
-    mpeg_jrevdct((int16 *)decblk);
-    distort += mse(current->y_blocks[y][x+1], decblk);
+        Mpost_QuantZigBlock(dct[y][x+1], fblk, qscale, TRUE);
+        Mpost_UnQuantZigBlock(fblk, decblk, qscale, TRUE);
+        if (collect_distortion_detailed) datarate += CalcRLEHuffLength(fblk);
+        mpeg_jrevdct((int16 *)decblk);
+        distort += mse(current->y_blocks[y][x+1], decblk);
 
-    Mpost_QuantZigBlock(dct[y+1][x], fblk, qscale, TRUE);
-    Mpost_UnQuantZigBlock(fblk, decblk, qscale, TRUE);
-    if (collect_distortion_detailed) datarate += CalcRLEHuffLength(fblk);
-    mpeg_jrevdct((int16 *)decblk);
-    distort += mse(current->y_blocks[y+1][x], decblk);
+        Mpost_QuantZigBlock(dct[y+1][x], fblk, qscale, TRUE);
+        Mpost_UnQuantZigBlock(fblk, decblk, qscale, TRUE);
+        if (collect_distortion_detailed) datarate += CalcRLEHuffLength(fblk);
+        mpeg_jrevdct((int16 *)decblk);
+        distort += mse(current->y_blocks[y+1][x], decblk);
 
-    Mpost_QuantZigBlock(dct[y+1][x+1], fblk, qscale, TRUE);
-    Mpost_UnQuantZigBlock(fblk, decblk, qscale, TRUE);
-    if (collect_distortion_detailed) datarate += CalcRLEHuffLength(fblk);
-    mpeg_jrevdct((int16 *)decblk);
-    distort += mse(current->y_blocks[y+1][x+1], decblk);
+        Mpost_QuantZigBlock(dct[y+1][x+1], fblk, qscale, TRUE);
+        Mpost_UnQuantZigBlock(fblk, decblk, qscale, TRUE);
+        if (collect_distortion_detailed) datarate += CalcRLEHuffLength(fblk);
+        mpeg_jrevdct((int16 *)decblk);
+        distort += mse(current->y_blocks[y+1][x+1], decblk);
 
-    Mpost_QuantZigBlock(dctb[y >> 1][x >> 1], fblk, qscale, TRUE);
-    Mpost_UnQuantZigBlock(fblk, decblk, qscale, TRUE);
-    if (collect_distortion_detailed) datarate += CalcRLEHuffLength(fblk);
-    mpeg_jrevdct((int16 *)decblk);
-    distort += mse(current->cb_blocks[y>>1][x>>1], decblk);
+        Mpost_QuantZigBlock(dctb[y >> 1][x >> 1], fblk, qscale, TRUE);
+        Mpost_UnQuantZigBlock(fblk, decblk, qscale, TRUE);
+        if (collect_distortion_detailed) datarate += CalcRLEHuffLength(fblk);
+        mpeg_jrevdct((int16 *)decblk);
+        distort += mse(current->cb_blocks[y>>1][x>>1], decblk);
 
-    Mpost_QuantZigBlock(dctr[y >> 1][x >> 1], fblk, qscale, TRUE);
-    Mpost_UnQuantZigBlock(fblk, decblk, qscale, TRUE);
-    if (collect_distortion_detailed) datarate += CalcRLEHuffLength(fblk);
-    mpeg_jrevdct((int16 *)decblk);
-    distort += mse(current->cr_blocks[y >> 1][x >> 1], decblk);
+        Mpost_QuantZigBlock(dctr[y >> 1][x >> 1], fblk, qscale, TRUE);
+        Mpost_UnQuantZigBlock(fblk, decblk, qscale, TRUE);
+        if (collect_distortion_detailed) datarate += CalcRLEHuffLength(fblk);
+        mpeg_jrevdct((int16 *)decblk);
+        distort += mse(current->cr_blocks[y >> 1][x >> 1], decblk);
 
-    if (!collect_distortion_detailed) {
-      fprintf(distortion_fp, "\t%d\n", distort);
-    } else if (collect_distortion_detailed == 1) {
-      fprintf(distortion_fp, "\t%d\t%d\n", distort, datarate);
-    } else {
-      fprintf(fp_table_rate[qscale-1], "%d\n", datarate);
-      fprintf(fp_table_dist[qscale-1], "%d\n", distort);
+        if (!collect_distortion_detailed) {
+            fprintf(distortion_fp, "\t%d\n", distort);
+        } else if (collect_distortion_detailed == 1) {
+            fprintf(distortion_fp, "\t%d\t%d\n", distort, datarate);
+        } else {
+            fprintf(fp_table_rate[qscale-1], "%d\n", datarate);
+            fprintf(fp_table_dist[qscale-1], "%d\n", distort);
+        }
     }
-  }
 }
 
 
