@@ -6,9 +6,10 @@ struct cmdlineInfo {
     /* All the information the user supplied in the command line,
        in a form easy for the program to use.
     */
-    const char *inputFilespec;  
-    const char *maskFilespec;  
+    const char * inputFilespec;  
+    const char * maskFilespec;  
     unsigned int verbose;
+    float        sharpness;
 };
 
 
@@ -26,11 +27,16 @@ parseCommandLine(int argc, char ** const argv,
     optStruct3 opt;
 
     unsigned int option_def_index;
+
+    unsigned int sharpSpec;
     
     MALLOCARRAY_NOFAIL(option_def, 100);
 
     option_def_index = 0;   /* incremented by OPTENTRY */
-    OPTENT3(0, "verbose",         OPT_FLAG,   NULL, &cmdlineP->verbose,   0);
+    OPTENT3(0, "sharpness",       OPT_FLOAT,  &cmdlineP->sharpness,
+            &sharpSpec,           0);
+    OPTENT3(0, "verbose",         OPT_FLAG,   NULL,
+            &cmdlineP->verbose,   0);
 
     opt.opt_table = option_def;
     opt.short_allowed = FALSE;  /* We have no short (old-fashioned) options */
@@ -39,6 +45,13 @@ parseCommandLine(int argc, char ** const argv,
     optParseOptions3(&argc, argv, opt, sizeof(opt), 0);
         /* Uses and sets argc, argv, and some of *cmdlineP and others. */
 
+    if (sharpSpec) {
+        if (cmdlineP->sharpness < 0)
+            pm_error("-sharpness less than zero doesn't make sense.  "
+                     "You specified %f", cmdlineP->sharpness);
+    } else
+        cmdlineP->sharpness = 1.0;
+
     if (argc-1 < 1)
         pm_error("You must specify at least one argument:  The name "
                  "of the mask image file");
@@ -65,11 +78,11 @@ main(int argc, char *argv[]) {
     struct pam inpam;
     struct pam maskpam;
     struct pam outpam;
-    FILE* ifP;
-    FILE* maskfP;
-    tuple* inputTuplerow;
-    tuple* maskTuplerow;
-    tuple* outputTuplerow;
+    FILE * ifP;
+    FILE * maskfP;
+    tuple * inputTuplerow;
+    tuple * maskTuplerow;
+    tuple * outputTuplerow;
     unsigned int row;
     
     pnm_init(&argc, argv);
@@ -114,11 +127,13 @@ main(int argc, char *argv[]) {
             unsigned int plane;
             
             for (plane = 0; plane < outpam.depth; ++plane) {
-                int const rawResult = 
-                    2 * inputTuplerow[col][plane] - maskTuplerow[col][plane];
-
+                int const edgeness = 
+                    inputTuplerow[col][plane] - maskTuplerow[col][plane];
+                float const rawResult = 
+                    inputTuplerow[col][plane] + edgeness * cmdline.sharpness;
+                
                 outputTuplerow[col][plane] =
-                    MIN(outpam.maxval, (unsigned)MAX(0, rawResult));
+                    MIN(outpam.maxval, (unsigned)MAX(0, (int)(rawResult+0.5)));
             }
         }
         pnm_writepamrow(&outpam, outputTuplerow);
