@@ -306,7 +306,7 @@ static int parse_enum (const char *const text,
 static number parse_float (char *const text)
 /*----------------------------------------------------------------------------
   Parse an argument given to a float command line option.  We cannot
-  just call strtod, because we want to support fractions like "5/3"
+  just call strtod, because we want to parse fractions like "5/3"
 -----------------------------------------------------------------------------*/
 {
   bool error;
@@ -335,7 +335,7 @@ static number parse_float (char *const text)
     num /= den;
     };
     break;
-  default:          /* It is no number format we support */
+  default:          /* It is no number format we know */
     error = TRUE;
   };
   if (error)
