@@ -416,16 +416,13 @@ struct colormapFinder {
     unsigned int colors;
         /* Number of colors in 'colormap'.  At least 1 */
     unsigned int distanceDivider;
-        /* The value by which our distance measurements have to be
-           divided to make sure we don't overlow our 'int' data
-           structure.
+        /* The value by which our intermediate distance calculations
+           have to be divided to make sure we don't overflow our
+           unsigned int data structure.
            
-           To the extent 'distanceDivider' is greater than 1, we will
-           return approximately the closest color -- there could
-           conceivably be a closer one that we miss.  If
-           'distanceDivider' is too small to ensure the calculation
-           doesn't overflow, then we will pick an arbitrary color as
-           closest, because of the possible arithmetic overflow.
+           To the extent 'distanceDivider' is greater than 1, closest
+           color results will be approximate -- there could
+           conceivably be a closer one that we miss.
         */
 };
 
@@ -445,20 +442,19 @@ createColormapFinder(struct pam *             const pamP,
     colormapFinderP->colors = colors;
 
     {
-        unsigned int const maxHandleableDiff = 
-            (unsigned int)sqrt(UINT_MAX / pamP->depth);
+        unsigned int const maxHandleableSqrDiff = 
+            (unsigned int)UINT_MAX / pamP->depth;
         
-        if (pamP->maxval > maxHandleableDiff)
-            colormapFinderP->distanceDivider = 
-                (unsigned int)(pamP->maxval / maxHandleableDiff + 0.1 + 1.0);
+        if (sqr(pamP->maxval) > maxHandleableSqrDiff)
+            colormapFinderP->distanceDivider = (unsigned int)
+                (sqr(pamP->maxval) / maxHandleableSqrDiff + 0.1 + 1.0);
                 /* The 0.1 is a fudge factor to keep us out of rounding 
                    trouble.  The 1.0 effects a round-up.
                 */
         else
             colormapFinderP->distanceDivider = 1;
-
-    *colormapFinderPP = colormapFinderP;
     }
+    *colormapFinderPP = colormapFinderP;
 }
 
 
@@ -470,6 +466,7 @@ destroyColormapFinder(struct colormapFinder * const colormapFinderP) {
 }
 
 
+
 static void
 searchColormapClose(struct pam *            const pamP,
                     tuple                   const tuple,
@@ -505,11 +502,13 @@ searchColormapClose(struct pam *            const pamP,
            tuple 'tuple' and a tuple in the colormap.  This is measured as
            the square of the cartesian distance between the tuples, except
            that it's divided by 'distanceDivider' to make sure it will fit
-           in an 'int'.
+           in an unsigned int.
         */
 
     dist = UINT_MAX;  /* initial value */
 
+    assert(colorFinderP->colors > 0);
+
     for (i = 0; i < colorFinderP->colors; ++i) {
         unsigned int newdist;  /* candidate for new 'dist' value */
         unsigned int plane;
