@@ -410,9 +410,9 @@ shearFinal(xel * const inRow,
            float const new0,
            int   const x2shearjunk) {
 
-    long const fracnew0 = ( new0 - (int) new0 ) * SCALE; 
+    long const fracnew0   = (new0 - (int) new0) * SCALE; 
     long const omfracnew0 = SCALE - fracnew0; 
-    int  const intnew0 = (int) new0 - x2shearjunk;
+    int  const intnew0    = (int) new0 - x2shearjunk;
 
     int col;
 
@@ -552,7 +552,7 @@ main(int argc, char *argv[]) {
     float xshearfac, yshearfac;
     enum rotationDirection direction;
 
-    pnm_init( &argc, argv );
+    pnm_init(&argc, argv);
 
     parseCommandLine(argc, argv, &cmdline);
 
@@ -633,6 +633,5 @@ main(int argc, char *argv[]) {
     pnm_freearray(temp2xels, newrows);
     pm_close(stdout);
     
-    exit( 0 );
+    return 0;
 }
-
