@@ -6,15 +6,14 @@
 #include <assert.h>
 #include <math.h>
 
-#include "ppm.h"
+#include "pm_c_util.h"
 #include "shhopt.h"
 #include "mallocvar.h"
 #include "nstring.h"
+#include "ppm.h"
 #include "ppmdraw.h"
 #include "ppmdfont.h"
 
-#define ARRAY_SIZE(x) (sizeof(x)/sizeof(x[0]))
-
 static bool verbose;
 
 
