@@ -92,7 +92,7 @@ main(int argc, char *argv[]) {
     pixel* pixrow;
     unsigned int row;
 
-    ppm_init( &argc, argv );
+    ppm_init(&argc, argv);
 
     parseCommandLine(argc, argv, &cmdline);
 
@@ -108,10 +108,6 @@ main(int argc, char *argv[]) {
 
     ppm_freerow(pixrow);
     pm_close(stdout);
-    exit(0);
+
+    return 0;
 }
-
-
-
-
-
