@@ -19,6 +19,7 @@
 
 #include <math.h>
 
+#include "pm_c_util.h"
 #include "mallocvar.h"
 #include "nstring.h"
 #include "pam.h"
@@ -29,6 +30,7 @@
 #include "colorname.h"
 #include "fileio.h"
 
+#include "libpam.h"
 
 char
 stripeq(const char * const comparand, const char * const comparator) {
@@ -499,15 +501,31 @@ parse_header_line(const char buffer[], char label[MAX_LABEL_LENGTH+1],
 
 
 
+struct headerSeen {
+/*----------------------------------------------------------------------------
+   This structure tells what we've seen so far in our progress through the
+   PAM header
+-----------------------------------------------------------------------------*/
+    bool width;
+    bool height;
+    bool depth;
+    bool maxval;
+    bool endhdr;
+};
+
+
+
 static void
-process_header_line(const char buffer[], struct pam * const pamP,
-                    int * const endofheaderP) {            
+process_header_line(char                const buffer[],
+                    struct pam *        const pamP,
+                    struct headerSeen * const headerSeenP) {
 /*----------------------------------------------------------------------------
    Process a line from the PAM header.  The line is buffer[], and it is not
    a comment or blank.
 
    Put the value that the line defines in *pamP (unless it's ENDHDR).
-   set *endofheader true if it's an ENDHDR line, false otherwise.
+
+   Update *headerSeenP with whatever we see.
 -----------------------------------------------------------------------------*/
     char label[MAX_LABEL_LENGTH+1];
     char value[MAX_VALUE_LENGTH+1];
@@ -515,10 +533,8 @@ process_header_line(const char buffer[], struct pam * const pamP,
     parse_header_line(buffer, label, value);
 
     if (strcmp(label, "ENDHDR") == 0)
-        *endofheaderP = TRUE;
+        headerSeenP->endhdr = TRUE;
     else {
-        *endofheaderP = FALSE;
-
         if (strcmp(label, "WIDTH") == 0 ||
             strcmp(label, "HEIGHT") == 0 ||
             strcmp(label, "DEPTH") == 0 ||
@@ -544,15 +560,19 @@ process_header_line(const char buffer[], struct pam * const pamP,
             }
         }
     
-        if (strcmp(label, "WIDTH") == 0) 
+        if (strcmp(label, "WIDTH") == 0) {
             pamP->width = atoi(value);
-        else if (strcmp(label, "HEIGHT") == 0) 
+            headerSeenP->width = TRUE;
+        } else if (strcmp(label, "HEIGHT") == 0) {
             pamP->height = atoi(value);
-        else if (strcmp(label, "DEPTH") == 0) 
+            headerSeenP->height = TRUE;
+        } else if (strcmp(label, "DEPTH") == 0) {
             pamP->depth = atoi(value);
-        else if (strcmp(label, "MAXVAL") == 0) 
+            headerSeenP->depth = TRUE;
+        } else if (strcmp(label, "MAXVAL") == 0) {
             pamP->maxval = atoi(value);
-        else if (strcmp(label, "TUPLTYPE") == 0) {
+            headerSeenP->maxval = TRUE;
+        } else if (strcmp(label, "TUPLTYPE") == 0) {
             int len = strlen(pamP->tuple_type);
             if (len + strlen(value) + 1 > sizeof(pamP->tuple_type)-1)
                 pm_error("TUPLTYPE value too long in PAM header");
@@ -579,9 +599,13 @@ readpaminitrest(struct pam * const pamP) {
 -----------------------------------------------------------------------------*/
     char buffer[256];
     char *rc;
-    int through_header;
+    struct headerSeen headerSeen;
 
-    bool widthSpec, heightSpec, depthSpec, maxvalSpec;
+    headerSeen.width  = FALSE;
+    headerSeen.height = FALSE;
+    headerSeen.depth  = FALSE;
+    headerSeen.maxval = FALSE;
+    headerSeen.endhdr = FALSE;
 
     pamP->tuple_type[0] = '\0';
 
@@ -593,8 +617,7 @@ readpaminitrest(struct pam * const pamP) {
         while ((c = getc(pamP->file)) != -1 && c != '\n');
     }    
 
-    through_header = FALSE;
-    while (!through_header) {
+    while (!headerSeen.endhdr) {
         rc = fgets(buffer, sizeof(buffer), pamP->file);
         if (rc == NULL)
             pm_error("EOF or error reading file while trying to read the "
@@ -605,16 +628,16 @@ readpaminitrest(struct pam * const pamP) {
             else if (stripeq(buffer, ""));
                 /* Ignore it; it's a blank line */
             else 
-                process_header_line(buffer, pamP, &through_header);
+                process_header_line(buffer, pamP, &headerSeen);
         }
     }
-    if (!heightSpec)
+    if (!headerSeen.height)
         pm_error("No HEIGHT header line in PAM header");
-    if (!widthSpec)
+    if (!headerSeen.width)
         pm_error("No WIDTH header line in PAM header");
-    if (!depthSpec)
+    if (!headerSeen.depth)
         pm_error("No DEPTH header line in PAM header");
-    if (!maxvalSpec)
+    if (!headerSeen.maxval)
         pm_error("No MAXVAL header line in PAM header");
 
     if (pamP->height == 0) 
@@ -632,10 +655,62 @@ readpaminitrest(struct pam * const pamP) {
 
 
 
+void
+pnm_readpaminitrestaspnm(FILE * const fileP, 
+                         int *  const colsP, 
+                         int *  const rowsP, 
+                         gray * const maxvalP,
+                         int *  const formatP) {
+/*----------------------------------------------------------------------------
+   Read the rest of the PAM header (after the first line) and return
+   information as if it were PPM or PGM.
+
+   Die if it isn't a PAM of the sort we can treat as PPM or PGM.
+-----------------------------------------------------------------------------*/
+    struct pam pam;
+
+    pam.size        = PAM_STRUCT_SIZE(tuple_type);
+    pam.file        = fileP;
+    pam.len         = sizeof(struct pam);
+    pam.format      = PAM_FORMAT;
+    pam.plainformat = 0;
+
+    readpaminitrest(&pam);
+
+
+    /* A PAM raster of depth 1 is identical to a PGM raster.  A PAM
+       raster of depth 3 is identical to PPM raster.  So
+       ppm_readppmrow() will be able to read the PAM raster as long as
+       the format it thinks it is (PGM or PPM) corresponds to the PAM
+       depth.  Similar for pgm_readpgmrow().
+    */
+    switch (pam.depth) {
+    case 3:
+        *formatP = RPPM_FORMAT;
+        break;
+    case 1:
+        *formatP = RPGM_FORMAT;
+        break;
+    default: {
+        pm_error("Cannot treat PAM image as PPM or PGM, "
+                 "because its depth (%u) "
+                 "is not 1 or 3.", pam.depth);
+    }
+    }
+
+    *colsP   = pam.width;
+    *rowsP   = pam.height;
+    *maxvalP = (gray)pam.maxval;
+}
+
+
+                
 unsigned int
 pnm_bytespersample(sample const maxval) {
 
-    if (maxval >> 8 == 0)       return 1;
+    assert(sizeof(maxval) * 8 <= 32);
+
+    if      (maxval >>  8 == 0) return 1;
     else if (maxval >> 16 == 0) return 2;
     else if (maxval >> 24 == 0) return 3;
     else                        return 4;
@@ -804,32 +879,32 @@ pnm_writepaminit(struct pam * const pamP) {
 
 void
 pnm_checkpam(const struct pam *   const pamP, 
-             enum pm_check_type   const check_type, 
-             enum pm_check_code * const retval_p) {
+             enum pm_check_type   const checkType, 
+             enum pm_check_code * const retvalP) {
 
-    if (check_type != PM_CHECK_BASIC) {
-        if (retval_p) *retval_p = PM_CHECK_UNKNOWN_TYPE;
+    if (checkType != PM_CHECK_BASIC) {
+        if (retvalP) *retvalP = PM_CHECK_UNKNOWN_TYPE;
     } else switch (PAM_FORMAT_TYPE(pamP->format)) {
     case PAM_TYPE: {
         pm_filepos const need_raster_size = 
             pamP->width * pamP->height * pamP->depth * pamP->bytes_per_sample;
-        pm_check(pamP->file, check_type, need_raster_size, retval_p);
+        pm_check(pamP->file, checkType, need_raster_size, retvalP);
     }
         break;
     case PPM_TYPE:
-        pgm_check(pamP->file, check_type, pamP->format, 
-                  pamP->width, pamP->height, pamP->maxval, retval_p);
+        pgm_check(pamP->file, checkType, pamP->format, 
+                  pamP->width, pamP->height, pamP->maxval, retvalP);
         break;
     case PGM_TYPE:
-        pgm_check(pamP->file, check_type, pamP->format, 
-                  pamP->width, pamP->height, pamP->maxval, retval_p);
+        pgm_check(pamP->file, checkType, pamP->format, 
+                  pamP->width, pamP->height, pamP->maxval, retvalP);
         break;
     case PBM_TYPE:
-        pbm_check(pamP->file, check_type, pamP->format, 
-                  pamP->width, pamP->height, retval_p);
+        pbm_check(pamP->file, checkType, pamP->format, 
+                  pamP->width, pamP->height, retvalP);
         break;
     default:
-        if (retval_p) *retval_p = PM_CHECK_UNCHECKABLE;
+        if (retvalP) *retvalP = PM_CHECK_UNCHECKABLE;
     }
 }
 
