@@ -232,28 +232,19 @@ pnm_readpamrow(const struct pam * const pamP,
        packed into one byte.
     */
 
-    switch (pamP->format) {
-    case PAM_FORMAT:
-    case RPPM_FORMAT:
-    case RPGM_FORMAT:
-        readRawNonPbmRow(pamP, tuplerow);
-        break;
-    case PPM_FORMAT:
-    case PGM_FORMAT:
-        readPlainNonPbmRow(pamP, tuplerow);
-        break;
-    case RPBM_FORMAT:
-    case PBM_FORMAT:
+    if (PAM_FORMAT_TYPE(pamP->format) == PBM_TYPE) 
         readPbmRow(pamP, tuplerow);
-        break;
-    default:
-        pm_error("Invalid 'format' member in PAM structure: %u", pamP->format);
+    else {
+        if (pamP->plainformat) 
+            readPlainNonPbmRow(pamP, tuplerow);
+        else
+            readRawNonPbmRow(pamP, tuplerow);
     }
 }
 
 
 
-tuple** 
+tuple ** 
 pnm_readpam(FILE *       const file, 
             struct pam * const pamP, 
             int          const size) {
