@@ -24,6 +24,9 @@
 #include "pbm.h"
 #include "libpbm.h"
 
+#include "pam.h"
+#include "libpam.h"
+
 #include "mallocvar.h"
 
 
@@ -87,11 +90,14 @@ pnm_readpnminit(FILE *   const fileP,
                 xelval * const maxvalP,
                 int *    const formatP) {
 
+    int realFormat;
+
     /* Check magic number. */
-    *formatP = pm_readmagicnumber(fileP);
-    switch (PNM_FORMAT_TYPE(*formatP)) {
+    realFormat = pm_readmagicnumber(fileP);
+    switch (PAM_FORMAT_TYPE(realFormat)) {
 	case PPM_TYPE: {
         pixval maxval;
+        *formatP = realFormat;
         ppm_readppminitrest(fileP, colsP, rowsP, &maxval);
         *maxvalP = maxval;
     }
@@ -100,16 +106,25 @@ pnm_readpnminit(FILE *   const fileP,
 	case PGM_TYPE: {
         gray maxval;
 
+        *formatP = realFormat;
         pgm_readpgminitrest(fileP, colsP, rowsP, &maxval);
         *maxvalP = maxval;
     }
     break;
 
 	case PBM_TYPE:
+        *formatP = realFormat;
         pbm_readpbminitrest(fileP, colsP, rowsP);
         *maxvalP = 1;
 	break;
 
+    case PAM_TYPE: {
+        gray maxval;
+        pnm_readpaminitrestaspnm(fileP, colsP, rowsP, &maxval, formatP);
+        *maxvalP = maxval;
+    }
+    break;
+
 	default:
         pm_error("bad magic number - not a ppm, pgm, or pbm file");
 	}
