@@ -248,7 +248,7 @@ pnm_makearrayrgb(const struct pam * const pamP,
 
 void
 pnm_getopacity(const struct pam * const pamP,
-               bool *             const haveOpacityP,
+               int *              const haveOpacityP,
                unsigned int *     const opacityPlaneP);
 
 void
@@ -324,7 +324,7 @@ pnm_writepam(struct pam * const pamP, tuple ** const tuplearray);
 
 void
 pnm_checkpam(const struct pam *   const pamP, 
-             const enum pm_check_type   check_type, 
+             enum pm_check_type   const checkType,
              enum pm_check_code * const retvalP);
 
 /*----------------------------------------------------------------------------
