@@ -55,23 +55,6 @@ extern "C" {
 #define PURE_FN_ATTR
 #endif
 
-#undef MAX
-#define MAX(a,b) ((a) > (b) ? (a) : (b))
-#undef MIN
-#define MIN(a,b) ((a) < (b) ? (a) : (b))
-#undef ABS
-#define ABS(a) ((a) >= 0 ? (a) : -(a))
-#undef SGN
-#define SGN(a)		(((a)<0) ? -1 : 1)
-#undef ODD
-#define ODD(n) ((n) & 1)
-#undef ROUND
-#define ROUND(X) (((X) >= 0) ? (int)((X)+0.5) : (int)((X)-0.5))
-#undef ROUNDU
-#define ROUNDU(X) ((unsigned int)((X)+0.5))
-#undef SQR
-#define SQR(a) ((a)*(a))
-
 /* Definitions to make Netpbm programs work with either ANSI C or C
    Classic.
 
