@@ -19,7 +19,7 @@
 #include "pam.h"
 #include "shhopt.h"
 
-enum function {FN_ADD, FN_SUBTRACT, FN_MULTIPLY, FN_DIFFERENCE,
+enum function {FN_ADD, FN_SUBTRACT, FN_MULTIPLY, FN_DIVIDE, FN_DIFFERENCE,
                FN_MINIMUM, FN_MAXIMUM, FN_MEAN, FN_COMPARE,
                FN_AND, FN_OR, FN_NAND, FN_NOR, FN_XOR,
                FN_SHIFTLEFT, FN_SHIFTRIGHT
@@ -50,15 +50,17 @@ parseCommandLine(int argc, char ** const argv,
 
     unsigned int option_def_index;
     
-    unsigned int addSpec, subtractSpec, multiplySpec, differenceSpec,
+    unsigned int addSpec, subtractSpec, multiplySpec, divideSpec,
+        differenceSpec,
         minimumSpec, maximumSpec, meanSpec, compareSpec,
-    andSpec, orSpec, nandSpec, norSpec, xorSpec,
-    shiftleftSpec, shiftrightSpec;
+        andSpec, orSpec, nandSpec, norSpec, xorSpec,
+        shiftleftSpec, shiftrightSpec;
 
     option_def_index = 0;   /* incremented by OPTENTRY */
     OPTENT3(0, "add",         OPT_FLAG,   NULL, &addSpec,        0);
     OPTENT3(0, "subtract",    OPT_FLAG,   NULL, &subtractSpec,   0);
     OPTENT3(0, "multiply",    OPT_FLAG,   NULL, &multiplySpec,   0);
+    OPTENT3(0, "divide",      OPT_FLAG,   NULL, &divideSpec,     0);
     OPTENT3(0, "difference",  OPT_FLAG,   NULL, &differenceSpec, 0);
     OPTENT3(0, "minimum",     OPT_FLAG,   NULL, &minimumSpec,    0);
     OPTENT3(0, "maximum",     OPT_FLAG,   NULL, &maximumSpec,    0);
@@ -79,7 +81,7 @@ parseCommandLine(int argc, char ** const argv,
     optParseOptions3(&argc, argv, opt, sizeof(opt), 0);
         /* Uses and sets argc, argv, and some of *cmdlineP and others. */
 
-    if (addSpec + subtractSpec + multiplySpec + differenceSpec +
+    if (addSpec + subtractSpec + multiplySpec + divideSpec + differenceSpec +
         minimumSpec + maximumSpec + meanSpec + compareSpec +
         andSpec + orSpec + nandSpec + norSpec + xorSpec +
         shiftleftSpec + shiftrightSpec > 1)
@@ -100,6 +102,8 @@ parseCommandLine(int argc, char ** const argv,
         cmdlineP->function = FN_SUBTRACT;
     else if (multiplySpec)
         cmdlineP->function = FN_MULTIPLY;
+    else if (divideSpec)
+        cmdlineP->function = FN_DIVIDE;
     else if (differenceSpec)
         cmdlineP->function = FN_DIFFERENCE;
     else if (minimumSpec)
@@ -130,7 +134,20 @@ parseCommandLine(int argc, char ** const argv,
 
 
 
-enum category {CATEGORY_FRACTIONAL_ARITH, CATEGORY_BITSTRING, CATEGORY_SHIFT};
+enum category {
+    CATEGORY_FRACTIONAL_ARITH,
+        /* Arithmetic in which each sample represents a the fraction
+           sample/maxval.
+        */
+    CATEGORY_BITSTRING,
+        /* And, Or, etc.  Maxval isn't a scale factor at all; it's a mask. */
+    CATEGORY_SHIFT
+        /* Left argument is a bit string, but right argument is a whole
+           number (left maxval is a mask; right maxval is meaningless).
+        */
+};
+
+
 
 static enum category
 functionCategory(enum function const function) {
@@ -140,12 +157,13 @@ functionCategory(enum function const function) {
     switch (function) {
     case FN_ADD:
     case FN_SUBTRACT:
-    case FN_MULTIPLY:
     case FN_DIFFERENCE:
     case FN_MINIMUM:
     case FN_MAXIMUM:
     case FN_MEAN:
     case FN_COMPARE:
+    case FN_MULTIPLY:
+    case FN_DIVIDE:
         retval = CATEGORY_FRACTIONAL_ARITH;
         break;
     case FN_AND:
@@ -164,6 +182,7 @@ functionCategory(enum function const function) {
 }
 
 
+
 static void
 computeOutputType(struct pam *  const outpamP,
                   struct pam    const inpam1,
@@ -216,71 +235,230 @@ computeOutputType(struct pam *  const outpamP,
 
 
 
-static sample
-applyFunction(enum function const function,
-              sample        const leftArg,
-              sample        const rightArg,
-              sample        const resultMaxval) {
+static samplen
+applyNormalizedFunction(enum function const function,
+                        samplen       const leftArg,
+                        samplen       const rightArg) {
 
-    sample retval;
-    double resultArith;
-    unsigned int resultBit;
+    samplen result;
 
     switch (function) {
     case FN_ADD:
-        resultArith = MIN(resultMaxval, leftArg + rightArg);
+        result = MIN(1., leftArg + rightArg);
         break;
     case FN_SUBTRACT:
-        resultArith = MAX(0, (int)leftArg - (int)rightArg);
+        result = MAX(0., leftArg - rightArg);
         break;
     case FN_MULTIPLY:
-        resultArith = leftArg * rightArg / resultMaxval;
+        result = leftArg * rightArg;
+        break;
+    case FN_DIVIDE:
+        result = (rightArg > leftArg) ?
+        leftArg / rightArg : 1.;
         break;
     case FN_DIFFERENCE:
-        resultArith = leftArg > rightArg ? 
+        result = leftArg > rightArg ? 
             leftArg - rightArg : rightArg - leftArg;
         break;
     case FN_MINIMUM:
-        resultArith = MIN(leftArg, rightArg);
+        result = MIN(leftArg, rightArg);
         break;
     case FN_MAXIMUM:
-        resultArith = MAX(leftArg, rightArg);
+        result = MAX(leftArg, rightArg);
         break;
     case FN_MEAN:
-        resultArith = (leftArg + rightArg) / 2.0;
+        result = (leftArg + rightArg) / 2.0;
         break;
     case FN_COMPARE:
-        resultArith = 
-            leftArg > rightArg ? 2 : leftArg < rightArg ? 0 : 1;
+        result = 
+            leftArg > rightArg ? 1. : leftArg < rightArg ? 0. : .5;
         break;
+    default:
+        pm_error("Internal error.  applyNormalizedFunction() called "
+                 "for a function it doesn't know how to do: %u", function);
+    }
+
+    return result;
+}
+
+
+
+static void
+doNormalizedArith(struct pam *  const inpam1P,
+                  struct pam *  const inpam2P,
+                  struct pam *  const outpamP,
+                  enum function const function) {
+
+    tuplen * tuplerown1;
+    tuplen * tuplerown2;
+    tuplen * tuplerownOut;
+    unsigned int row;
+
+    tuplerown1   = pnm_allocpamrown(inpam1P);
+    tuplerown2   = pnm_allocpamrown(inpam2P);
+    tuplerownOut = pnm_allocpamrown(outpamP);
+
+    for (row = 0; row < outpamP->height; ++row) {
+        unsigned int col;
+        pnm_readpamrown(inpam1P, tuplerown1);
+        pnm_readpamrown(inpam2P, tuplerown2);
+        
+        for (col = 0; col < outpamP->width; ++col) {
+            unsigned int outplane;
+            
+            for (outplane = 0; outplane < outpamP->depth; ++outplane) {
+                unsigned int const plane1 = MIN(outplane, inpam1P->depth-1);
+                unsigned int const plane2 = MIN(outplane, inpam2P->depth-1);
+
+                tuplerownOut[col][outplane] = 
+                    applyNormalizedFunction(function, 
+                                            tuplerown1[col][plane1], 
+                                            tuplerown2[col][plane2]);
+                assert(tuplerownOut[col][outplane] >= 0.);
+                assert(tuplerownOut[col][outplane] <= 1.);
+
+            }
+        }
+        pnm_writepamrown(outpamP, tuplerownOut);
+    }
+
+    pnm_freepamrown(tuplerown1);
+    pnm_freepamrown(tuplerown2);
+    pnm_freepamrown(tuplerownOut);
+}
+
+
+
+static sample
+applyUnNormalizedFunction(enum function const function,
+                          sample        const leftArg,
+                          sample        const rightArg,
+                          sample        const maxval) {
+/*----------------------------------------------------------------------------
+   Apply dyadic function 'function' to the arguments 'leftArg' and
+   'rightArg', assuming both are based on the same maxval 'maxval'.
+   Return a value which is also a fraction of 'maxval'.
+
+   Exception: for the shift operations, 'rightArg' is not based on any
+   maxval.  It is an absolute bit count.
+-----------------------------------------------------------------------------*/
+    sample result;
+
+    switch (function) {
+    case FN_ADD:
+        result = MIN(maxval, leftArg + rightArg);
+        break;
+    case FN_SUBTRACT:
+        result = MAX(0, (int)leftArg - (int)rightArg);
+        break;
+    case FN_DIFFERENCE:
+        result = leftArg > rightArg ? leftArg - rightArg : rightArg - leftArg;
+        break;
+    case FN_MINIMUM:
+        result = MIN(leftArg, rightArg);
+        break;
+    case FN_MAXIMUM:
+        result = MAX(leftArg, rightArg);
+        break;
+    case FN_MEAN:
+        result = (leftArg + rightArg + 1) / 2;
+        break;
+    case FN_COMPARE:
+        result = leftArg > rightArg ? 2 : leftArg < rightArg ? 0 : 1;
+        break;
+    case FN_MULTIPLY:
+        result = (leftArg * rightArg + maxval/2) / maxval;
+        break;
+    case FN_DIVIDE:
+        result = (rightArg > leftArg) ?
+            (leftArg * maxval + rightArg/2) / rightArg : maxval;
+        break;
+
     case FN_AND:
-        resultBit = leftArg & rightArg;
+        result = leftArg & rightArg;
         break;
     case FN_OR:
-        resultBit = leftArg | rightArg;
+        result = leftArg | rightArg;
         break;
     case FN_NAND:
-        resultBit = ~(leftArg & rightArg) & resultMaxval;
+        result = ~(leftArg & rightArg) & maxval;
         break;
     case FN_NOR:
-        resultBit = ~(leftArg | rightArg) & resultMaxval;
+        result = ~(leftArg | rightArg) & maxval;
         break;
     case FN_XOR:
-        resultBit = leftArg ^ rightArg;
+        result = leftArg ^ rightArg;
         break;
     case FN_SHIFTLEFT:
-        resultBit = (leftArg << rightArg) & resultMaxval;
+        result = (leftArg << rightArg) & maxval;
         break;
     case FN_SHIFTRIGHT:
-        resultBit = leftArg >> rightArg;
+        result = leftArg >> rightArg;
         break;
+    default:
+        pm_error("Internal error.  applyUnNormalizedFunction() called "
+                 "for a function it doesn't know how to do: %u", function);
     }
-    if (functionCategory(function) == CATEGORY_FRACTIONAL_ARITH)
-        retval = (sample) (resultArith + 0.5);
-    else
-        retval = resultBit;
 
-    return retval;
+    return result;
+}
+
+
+
+static void
+doUnNormalizedArith(struct pam *  const inpam1P,
+                    struct pam *  const inpam2P,
+                    struct pam *  const outpamP,
+                    enum function const function) {
+/*----------------------------------------------------------------------------
+   Take advantage of the fact that both inputs and the output use the same
+   maxval to do the computation without time-consuming normalization of
+   sample values.
+-----------------------------------------------------------------------------*/
+    sample const maxval = outpamP->maxval;
+
+    tuple * tuplerow1;
+    tuple * tuplerow2;
+    tuple * tuplerowOut;
+    unsigned int row;
+
+    /* Input conditions: */
+    assert(inpam1P->maxval == maxval);
+    assert(inpam2P->maxval == maxval);
+    assert(outpamP->maxval == maxval);
+
+    tuplerow1   = pnm_allocpamrow(inpam1P);
+    tuplerow2   = pnm_allocpamrow(inpam2P);
+    tuplerowOut = pnm_allocpamrow(outpamP);
+
+    for (row = 0; row < outpamP->height; ++row) {
+        unsigned int col;
+        pnm_readpamrow(inpam1P, tuplerow1);
+        pnm_readpamrow(inpam2P, tuplerow2);
+        
+        for (col = 0; col < outpamP->width; ++col) {
+            unsigned int outplane;
+            
+            for (outplane = 0; outplane < outpamP->depth; ++outplane) {
+                unsigned int const plane1 = MIN(outplane, inpam1P->depth-1);
+                unsigned int const plane2 = MIN(outplane, inpam2P->depth-1);
+
+                tuplerowOut[col][outplane] = 
+                    applyUnNormalizedFunction(function, 
+                                              tuplerow1[col][plane1], 
+                                              tuplerow2[col][plane2],
+                                              maxval);
+
+                assert(tuplerowOut[col][outplane] >= 0);
+                assert(tuplerowOut[col][outplane] <= outpamP->maxval);
+            }
+        }
+        pnm_writepamrow(outpamP, tuplerowOut);
+    }
+
+    pnm_freepamrow(tuplerow1);
+    pnm_freepamrow(tuplerow2);
+    pnm_freepamrow(tuplerowOut);
 }
 
 
@@ -292,12 +470,8 @@ main(int argc, char *argv[]) {
     struct pam inpam1;
     struct pam inpam2;
     struct pam outpam;
-    FILE* if1P;
-    FILE* if2P;
-    tuple* tuplerow1;
-    tuple* tuplerow2;
-    tuple* tuplerowOut;
-    unsigned int row;
+    FILE * if1P;
+    FILE * if2P;
     
     pnm_init(&argc, argv);
 
@@ -311,59 +485,34 @@ main(int argc, char *argv[]) {
 
     if (inpam1.width != inpam2.width || inpam1.height != inpam2.height)
         pm_error("The two images must be the same width and height.  "
-                 "The first is %dx%dx%d, but the second is %dx%dx%d",
+                 "The first is %ux%ux%u, but the second is %ux%ux%u",
                  inpam1.width, inpam1.height, inpam1.depth,
                  inpam2.width, inpam2.height, inpam2.depth);
 
     if (inpam1.depth != 1 && inpam2.depth != 1 && inpam1.depth != inpam2.depth)
         pm_error("The two images must have the same depth or one of them "
-                 "must have depth 1.  The first has depth %d and the second "
-                 "has depth %d", inpam1.depth, inpam2.depth);
+                 "must have depth 1.  The first has depth %u and the second "
+                 "has depth %u", inpam1.depth, inpam2.depth);
 
     computeOutputType(&outpam, inpam1, inpam2, cmdline.function);
 
-    tuplerow1 = pnm_allocpamrow(&inpam1);
-    tuplerow2 = pnm_allocpamrow(&inpam2);
-    tuplerowOut = pnm_allocpamrow(&outpam);
-
     pnm_writepaminit(&outpam);
 
-    for (row = 0; row < outpam.height; ++row) {
-        unsigned int col;
-        pnm_readpamrow(&inpam1, tuplerow1);
-        pnm_readpamrow(&inpam2, tuplerow2);
-        
-        if (outpam.maxval != inpam1.maxval)
-            pnm_scaletuplerow(&inpam1, tuplerow1, tuplerow1, outpam.maxval);
-        if (outpam.maxval != inpam2.maxval)
-            pnm_scaletuplerow(&inpam2, tuplerow2, tuplerow2, outpam.maxval);
-
-        for (col = 0; col < outpam.width; ++col) {
-            unsigned int outplane;
-            
-            for (outplane = 0; outplane < outpam.depth; ++outplane) {
-                unsigned int const plane1 = MIN(outplane, inpam1.depth-1);
-                unsigned int const plane2 = MIN(outplane, inpam2.depth-1);
-
-                tuplerowOut[col][outplane] = 
-                    applyFunction(cmdline.function, 
-                                  tuplerow1[col][plane1], 
-                                  tuplerow2[col][plane2],
-                                  outpam.maxval);
-
-                assert(tuplerowOut[col][outplane] >= 0);
-                assert(tuplerowOut[col][outplane] <= outpam.maxval);
-            }
-        }
-        pnm_writepamrow(&outpam, tuplerowOut);
+    switch (functionCategory(cmdline.function)) {    
+    case CATEGORY_FRACTIONAL_ARITH:
+        if (inpam1.maxval == inpam2.maxval)
+            doUnNormalizedArith(&inpam1, &inpam2, &outpam, cmdline.function);
+        else
+            doNormalizedArith(&inpam1, &inpam2, &outpam, cmdline.function);
+        break;
+    case CATEGORY_BITSTRING:
+    case CATEGORY_SHIFT:
+        doUnNormalizedArith(&inpam1, &inpam2, &outpam, cmdline.function);
+        break;
     }
 
     pm_close(if1P);
     pm_close(if2P);
-
-    pnm_freepamrow(tuplerow1);
-    pnm_freepamrow(tuplerow2);
-    pnm_freepamrow(tuplerowOut);
     
     return 0;
 }
