@@ -54,45 +54,6 @@
 #endif
 
 
-/* NOTE: do not use "bool" as a type in an external interface.  It could
-   have different definitions on either side of the interface.  Even if both
-   sides include this interface header file, the conditional compilation
-   here means one side may use the typedef below and the other side may
-   use some other definition.  For an external interface, be safe and just
-   use "int".
-*/
-
-/* We used to assume that if TRUE was defined, then bool was too.
-   However, we had a report on 2001.09.21 of a Tru64 system that had
-   TRUE but not bool and on 2002.03.21 of an AIX 4.3 system that was
-   likewise.  So now we define bool all the time, unless the macro
-   HAVE_BOOL is defined.  If someone is using the Netpbm libraries and
-   also another library that defines bool, he can either make the
-   other library define/respect HAVE_BOOL or just define HAVE_BOOL in
-   the file that includes pm_config.h or with a compiler option.  Note
-   that C++ always has bool.  
-
-   A preferred way of getting booleans is <stdbool.h>.  But it's not
-   available on all platforms, and it's easy to reproduce what it does
-   here.
-*/
-#ifndef TRUE
-  #define TRUE 1
-  #endif
-#ifndef FALSE
-  #define FALSE 0
-  #endif
-/* C++ has a bool type and false and true constants built in. */
-#ifndef __cplusplus
-  #ifndef HAVE_BOOL
-    #define HAVE_BOOL 1
-    typedef int bool;
-    #endif
-  #ifndef true
-    enum boolvalue {false=0, true=1};
-    #endif
-  #endif
-
 /* CONFIGURE: If you have an X11-style rgb color names file, define its
 ** path here.  This is used by PPM to parse color names into rgb values.
 ** If you don't have such a file, comment this out and use the alternative
@@ -117,24 +78,6 @@
 */
 #define RGBENV "RGBDEF"    /* name of env-var */
 
-/* CONFIGURE: Normally, PPM handles a pixel as a struct of three grays.
-** If grays are represented as chars, that's 24 bits per color pixel; if
-** grays are represented as ints, that's usually 96 bits per color pixel.  PPM
-** can be modified to pack the three samples into a single longword,
-** 10 bits each, for 32 bits per pixel.
-**
-** If you don't need more than 10 bits for each color component, AND
-** you care more about memory use than speed, then this option might
-** be a win.  Under these circumstances it will make some of the
-** programs use 3 times less space, but all of the programs will run
-** slower.  In one test, it was 1.4 times slower.
-** 
-*/
-/* #define PPM_PACKCOLORS */
-
-/* CONFIGURE: uncomment this to enable debugging checks. */
-/* #define DEBUG */
-
 #if (defined(SYSV) || defined(__amigaos__))
 
 #include <string.h>
